import uuid
import platform
import subprocess
import qrcode
import qrcode_terminal
import os
import requests
from io import BytesIO
import psutil
import pynvml

from PIL import Image
from qrcode.image.styledpil import StyledPilImage
from qrcode.image.styles.moduledrawers import RoundedModuleDrawer, SquareModuleDrawer, CircleModuleDrawer
from qrcode.image.styles.colormasks import RadialGradiantColorMask, SquareGradiantColorMask, SolidFillColorMask

def get_mac_address():
    if platform.system() == 'Windows':
        cmd = "ipconfig /all"
        output = subprocess.check_output(cmd, shell=True)
        output_str = output.decode('gbk')
        pos = output_str.find('Physical Address')
        if pos == -1:
            pos = output_str.find('物理地址')
        mac = (output_str[pos:pos+100].split(':')[1]).strip().replace('-', '')
    elif platform.system() == 'Linux' or platform.system() == 'Darwin':
        cmd = "ifconfig"
        output = subprocess.check_output(cmd, shell=True)
        output_str = output.decode('utf-8')
        mac = output_str[output_str.index('ether') + 6:output_str.index('ether') + 23].replace(':', '')
    else:
        mac = None
    return mac

def get_cpu_serial():
    cpu_serial = ""
    if platform.system() == 'Windows':
        cmd = "wmic cpu get ProcessorId"
        output = subprocess.check_output(cmd, shell=True)
        output_str = output.decode('gbk')
        pos = output_str.index("\n")
        cpu_serial = output_str[pos:].strip()
    elif platform.system() == 'Linux':
        with open('/proc/cpuinfo') as f:
            
            for line in f:
                print(line)
                print ("----------- \n")
                if line[0:6] == 'Serial':
                    return "1"
                if line.strip().startswith('serial'):
                    cpu_serial = line.split(":")[1].strip()
                    break
        if not cpu_serial:
            cpu_serial = None
    elif platform.system() == 'Darwin':
        cmd = "/usr/sbin/system_profiler SPHardwareDataType"
        output = subprocess.check_output(cmd, shell=True)
        output_str = output.decode('utf-8')
        cpu_serial = output_str[output_str.index('Hardware UUID:') + 14:output_str.index('Hardware UUID:') + 51].replace('-', '')
    else:
        cpu_serial = None
    return cpu_serial

def generate_unique_id():
    mac = get_mac_address()
    cpu_serial = get_cpu_serial()
    if mac and cpu_serial:
        unique_id = uuid.uuid5(uuid.NAMESPACE_DNS, mac + cpu_serial)
        return str(unique_id).replace('-', '')
    if mac :
        unique_id = uuid.uuid5(uuid.NAMESPACE_DNS, mac)
        return str(unique_id).replace('-', '')

def displayQrcode(s):
    qr = qrcode.QRCode(
        version=4,
        error_correction=qrcode.constants.ERROR_CORRECT_H,
        box_size=10,
        border=4
        )
    qr.add_data(s)
    qr.make(fit=True)
    img = qr.make_image(
        image_factory=StyledPilImage, 
        module_drawer=CircleModuleDrawer(),
        color_mask=SolidFillColorMask(),
        fill_color=(0, 0, 0),
        back_color=(255,255,255))
    
    cache_qrcode_file = os.path.join(os.path.dirname(os.path.abspath(__file__)), "login_qrcode.png")
    img.save(cache_qrcode_file)
    if platform.system() == 'Windows':
        os.system(f"start {cache_qrcode_file} &")
    elif platform.system() == 'Linux' or platform.system() == 'Darwin':
        qrcode_terminal.draw(s)

def displayQRcodeOnTerminal(s):
    qrcode_terminal.draw(s)

def getOssImageSize(p):
    try:
        res = requests.get(p)
        image = Image.open(BytesIO(res.content), "r")
        return image.size
    except:
        return 0, 0
    
def deviceInfo():
    pynvml.nvmlInit()
    gpuCount = pynvml.nvmlDeviceGetCount()
    M=1024*1024
    data = {
        "cpu": {
            "logical_count" : psutil.cpu_count(),
            "count" : psutil.cpu_count(logical=False),
            "max_freq" : f"{psutil.cpu_freq().max / 1000} GHz",
        },
        "memory": {
            "total" : f"{psutil.virtual_memory().total/M} M",
            "free" : f"{psutil.virtual_memory().free/M} M"
        },
        "gpu": {
            "count" : gpuCount,
            "list" : [],
            "mem" : []
        }
    }
    for i in range(gpuCount):
        handle = pynvml.nvmlDeviceGetHandleByIndex(i)
        data["gpu"]["list"].append(f"GPU{i}: {pynvml.nvmlDeviceGetName(handle)}")
        memInfo = pynvml.nvmlDeviceGetMemoryInfo(handle)
        data["gpu"]["mem"].append(f"GPU{i}: total:{memInfo.total/M} M free:{memInfo.free/M} M")
        
    pynvml.nvmlShutdown()
    return data


import os
import json
import sys
import shutil
import zipfile
import pkg_resources
import threading
import time
import requests
import random

from pathlib import Path
from mecord import store
from mecord import xy_pb
from mecord import upload
from mecord import utils

h5_name = "h5"
script_name = "script"
def GetWidgetConfig(path):
    #search h5 folder first, netxt search this folder
    if os.path.exists(os.path.join(path, h5_name)):
        for filename in os.listdir(os.path.join(path, h5_name)):
            pathname = os.path.join(path, h5_name, filename) 
            if (os.path.isfile(pathname)) and filename == "config.json":
                with open(pathname, 'r') as f:
                    return json.load(f)
    for filename in os.listdir(path):
        pathname = os.path.join(path, filename) 
        if (os.path.isfile(pathname)) and filename == "config.json":
            with open(pathname, 'r') as f:
                return json.load(f)
    return {}
    
def configInFolder(path):
    for filename in os.listdir(path):
        pathname = os.path.join(path, filename) 
        if (os.path.isfile(pathname)) and filename == "config.json":
            return True
    return False

def PathIsEmpty(path):
    return len(os.listdir(path)) == 0

def checkImportMecordJs(h5Root):
    jsPath = os.path.join(h5Root, "MekongJS.js")
    jsPathTmp = os.path.join(h5Root, "MekongJS.js.py")
    js_res = requests.get(f"https://www.mecordai.com/prod/mecord/commonality/MecordJS/MecordJS.min.js?t={random.randint(100,99999999)}")
    with open(jsPathTmp, "wb") as c:
        c.write(js_res.content)
    if os.path.exists(jsPathTmp):
        if os.path.exists(jsPath):
            os.remove(jsPath)
        os.rename(jsPathTmp, jsPath)


def replaceIfNeed(dstDir, name, subfix):
    newsubfix = subfix + ".py"
    if name.find(newsubfix) != -1:
        os.rename(os.path.join(dstDir, name), os.path.join(dstDir, name.replace(newsubfix, subfix)))

def copyWidgetTemplate(root, name, dirname):
    templateDir = os.path.join(os.path.dirname(os.path.abspath(__file__)), name)#sys.prefix
    dstDir = os.path.join(root, dirname)
    shutil.copytree(templateDir, dstDir)
    shutil.rmtree(os.path.join(dstDir, "__pycache__"))
    os.remove(os.path.join(dstDir, "__init__.py"))
    for filename in os.listdir(dstDir):
        replaceIfNeed(dstDir, filename, ".json")
        replaceIfNeed(dstDir, filename, ".js")
        replaceIfNeed(dstDir, filename, ".png")
        replaceIfNeed(dstDir, filename, ".html")

def createDemoWidget():
    path = os.path.join(os.path.dirname(os.path.abspath(__file__)), "demo")
    if os.path.exists(path):
        shutil.rmtree(path)
    os.makedirs(path)
    createWidget(path)
    publishWidget(path)

def createWidget(root):
    if PathIsEmpty(root) == False:
        print("current folder is not empty, create widget fail!")
        return
        
    widgetid = xy_pb.CreateWidgetUUID()
    if len(widgetid) == 0:
        print("create fail! mecord server is not avalid")
        return
    
    copyWidgetTemplate(root, "widget_template", h5_name)
    copyWidgetTemplate(root, "script_template", script_name)
    #h5
    data = GetWidgetConfig(root)
    data["widget_id"] = widgetid
    data["group_id"] = store.groupUUID()
    data["device_keys"] = [
        utils.generate_unique_id()
    ]
    data["cmd"] = os.path.join(root, script_name, "main.py")
    with open(os.path.join(root, h5_name, "config.json"), 'w') as f:
        json.dump(data, f)
    checkImportMecordJs(os.path.join(root, h5_name))
    #script
    with open(os.path.join(root, script_name, "config.json"), 'w') as f:
        json.dump({"widget_id": widgetid}, f)
    addWidget(os.path.join(root, script_name))
    print("create widget success")

def CheckWidgetDataInPath(path):
    data = GetWidgetConfig(path)
    if "widget_id" not in data:
        print("folder is not widget")
        return False

    if "widget_id" in data:
        widget_id = data["widget_id"]
        if len(widget_id) == 0:
            print("widget_id is empty!")
            return False
        
    return True

def addWidget(root):
    if CheckWidgetDataInPath(root) == False:
        return
        
    data = GetWidgetConfig(root)
    widget_id = data["widget_id"]
    mainPythonPath = os.path.join(root, "main.py")
    if os.path.exists(os.path.join(root, script_name)):
        mainPythonPath = os.path.join(root, script_name, "main.py")
    if store.insertWidgets(widget_id, mainPythonPath):
        print(f"add {widget_id.ljust(len(widget_id)+4)} {mainPythonPath}")

def publishWidget(root):
    if CheckWidgetDataInPath(root) == False:
        return
        
    data = GetWidgetConfig(root)
    widget_id = data["widget_id"]

    distname = utils.generate_unique_id() + "_" + widget_id
    dist = os.path.join(os.path.dirname(root), distname + ".zip")
    zip = zipfile.ZipFile(dist, "w", zipfile.ZIP_DEFLATED) 

    #h5 folder
    package_folder = ""
    if configInFolder(root):
        package_folder = root
    elif configInFolder(os.path.join(root, h5_name)):
        package_folder = os.path.join(root, h5_name)

    checkImportMecordJs(package_folder)
    for root,dirs,files in os.walk(package_folder):
        for file in files:
            if str(file).startswith("~$"):
                continue
            filepath = os.path.join(root, file)
            writepath = os.path.relpath(filepath, package_folder)
            zip.write(filepath, writepath)
    zip.close()

    (ossurl, checkid) = upload.uploadWidget(dist, widget_id)
    if checkid > 0:
        checkUploadComplete(checkid, dist)
    else:
        os.remove(dist)

def checkUploadComplete(checkid, dist):
    rst = xy_pb.UploadWidgetCheck(checkid)
    if rst == 1: #success
        print("publish widget success")
        # xy_pb.UploadWidget(widget_id, ossurl)  #暂时不用
        os.remove(dist)
        store.finishCreateWidget()
    elif rst == -1:
        threading.Timer(1, checkUploadComplete, (checkid, dist, )).start()
    else: #fail
        print("publish fail")
        return


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aigc_ext.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from mecord import common_ext_pb2 as common__ext__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x61igc_ext.proto\x12\x02pb\x1a\x10\x63ommon_ext.proto\"J\n\x08TaskItem\x12\x0e\n\x06taskId\x18\x01 \x01(\x03\x12\x10\n\x08taskUUID\x18\x02 \x01(\t\x12\x0e\n\x06\x63onfig\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\t\"o\n\nGetTaskReq\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x11\n\tDeviceKey\x18\x02 \x01(\t\x12\x0f\n\x07widgets\x18\x03 \x03(\t\x12\r\n\x05token\x18\x04 \x01(\t\x12\r\n\x05limit\x18\x05 \x01(\x05\x12\x0e\n\x06\x65xtend\x18\x06 \x01(\t\"F\n\nGetTaskRes\x12\x1a\n\x04list\x18\x01 \x03(\x0b\x32\x0c.pb.TaskItem\x12\r\n\x05limit\x18\x02 \x01(\x05\x12\r\n\x05\x63ount\x18\x03 \x01(\x03\"x\n\rTaskNotifyReq\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x10\n\x08taskUUID\x18\x02 \x01(\t\x12\"\n\ntaskStatus\x18\x03 \x01(\x0e\x32\x0e.pb.TaskStatus\x12\x12\n\nfailReason\x18\x04 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x05 \x01(\t\"\x0f\n\rTaskNotifyRes\"o\n\x11\x41igcDeviceBindReq\x12\x11\n\tdeviceKey\x18\x01 \x01(\t\x12\x11\n\tGroupUUID\x18\x02 \x01(\t\x12 \n\tLabelType\x18\x03 \x01(\x0e\x32\r.pb.LabelType\x12\x12\n\nlabelValue\x18\x04 \x01(\t\"\x13\n\x11\x41igcDeviceBindRes\":\n\x13\x41igcDeviceUnBindReq\x12\x10\n\x08\x64\x65viceId\x18\x01 \x01(\x03\x12\x11\n\tdeviceKey\x18\x02 \x01(\t\"\x15\n\x13\x41igcDeviceUnBindRes\"7\n\x11\x41igcDeviceInfoReq\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x11\n\tdeviceKey\x18\x02 \x01(\t\"`\n\x11\x41igcDeviceInfoRes\x12\x11\n\tdeviceKey\x18\x01 \x01(\t\x12\x11\n\tgroupUUID\x18\x02 \x01(\t\x12\x16\n\x0eisCreateWidget\x18\x03 \x01(\x08\x12\r\n\x05token\x18\x04 \x01(\t\"\x11\n\x0f\x43reateWidgetReq\"%\n\x0f\x43reateWidgetRes\x12\x12\n\nwidgetUUID\x18\x01 \x01(\t\"9\n\x12UploadWidgetUrlReq\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x12\n\nwidgetUUID\x18\x02 \x01(\t\"6\n\x12UploadWidgetUrlRes\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x13\n\x0b\x63ontentType\x18\x02 \x01(\t\"3\n\x0fUploadWidgetReq\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x0f\n\x07\x66ileUrl\x18\x02 \x01(\t\"\"\n\x0fUploadWidgetRes\x12\x0f\n\x07\x63heckId\x18\x01 \x01(\x03\"8\n\x14UploadWidgetCheckReq\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x0f\n\x07\x63heckId\x18\x02 \x01(\x03\"R\n\x14UploadWidgetCheckRes\x12&\n\x06status\x18\x01 \x01(\x0e\x32\x16.pb.UploadWidgetStatus\x12\x12\n\nfailReason\x18\x02 \x01(\t\"\x88\x01\n\x12\x41igcCreateGroupReq\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12 \n\tlabelType\x18\x05 \x01(\x0e\x32\r.pb.LabelType\x12\x0f\n\x07labelId\x18\x06 \x01(\x03\x12\x0e\n\x06status\x18\x07 \x01(\x05\".\n\x12\x41igcCreateGroupRes\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04uuid\x18\x02 \x01(\t\"V\n\x12\x41igcRemoveGroupReq\x12\n\n\x02id\x18\x01 \x01(\x03\x12 \n\tlabelType\x18\x02 \x01(\x0e\x32\r.pb.LabelType\x12\x12\n\nlabelValue\x18\x03 \x01(\t\"\x14\n\x12\x41igcRemoveGroupRes\",\n\x0e\x41igcTaskResult\x12\x1a\n\x04list\x18\x01 \x03(\x0b\x32\x0c.pb.AigcData\"S\n\x08\x41igcData\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x03(\t\x12(\n\textension\x18\x03 \x01(\x0b\x32\x15.pb.AigcDataExtension\"S\n\x11\x41igcDataExtension\x12\x0c\n\x04info\x18\x01 \x01(\t\x12\x11\n\tcover_url\x18\x02 \x01(\t\x12\x0e\n\x06height\x18\x03 \x01(\t\x12\r\n\x05width\x18\x04 \x01(\t\"C\n\x10UploadFileUrlReq\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\r\n\x05token\x18\x02 \x01(\t\x12\x0f\n\x07\x66ileExt\x18\x03 \x01(\t\"4\n\x10UploadFileUrlRes\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x13\n\x0b\x63ontentType\x18\x02 \x01(\t*X\n\x12UploadWidgetStatus\x12\x0c\n\x08UWS_NONE\x10\x00\x12\x12\n\x0eUWS_PROCESSING\x10\x01\x12\x0f\n\x0bUWS_SUCCESS\x10\x02\x12\x0f\n\x0bUWS_FAILURE\x10\x03\x32\xdf\x04\n\nAigcExtObj\x12)\n\x07GetTask\x12\x0e.pb.GetTaskReq\x1a\x0e.pb.GetTaskRes\x12\x32\n\nTaskNotify\x12\x11.pb.TaskNotifyReq\x1a\x11.pb.TaskNotifyRes\x12:\n\nDeviceBind\x12\x15.pb.AigcDeviceBindReq\x1a\x15.pb.AigcDeviceBindRes\x12:\n\nDeviceInfo\x12\x15.pb.AigcDeviceInfoReq\x1a\x15.pb.AigcDeviceInfoRes\x12\x38\n\x0c\x43reateWidget\x12\x13.pb.CreateWidgetReq\x1a\x13.pb.CreateWidgetRes\x12\x38\n\x0cUploadWidget\x12\x13.pb.UploadWidgetReq\x1a\x13.pb.UploadWidgetRes\x12\x41\n\x0fUploadWidgetUrl\x12\x16.pb.UploadWidgetUrlReq\x1a\x16.pb.UploadWidgetUrlRes\x12;\n\rUploadFileUrl\x12\x14.pb.UploadFileUrlReq\x1a\x14.pb.UploadFileUrlRes\x12G\n\x11UploadWidgetCheck\x12\x18.pb.UploadWidgetCheckReq\x1a\x18.pb.UploadWidgetCheckRes\x12=\n\x0bRemoveGroup\x12\x16.pb.AigcRemoveGroupReq\x1a\x16.pb.AigcRemoveGroupResB\x06\xa2\x02\x03PB3b\x06proto3')

_UPLOADWIDGETSTATUS = DESCRIPTOR.enum_types_by_name['UploadWidgetStatus']
UploadWidgetStatus = enum_type_wrapper.EnumTypeWrapper(_UPLOADWIDGETSTATUS)
UWS_NONE = 0
UWS_PROCESSING = 1
UWS_SUCCESS = 2
UWS_FAILURE = 3


_TASKITEM = DESCRIPTOR.message_types_by_name['TaskItem']
_GETTASKREQ = DESCRIPTOR.message_types_by_name['GetTaskReq']
_GETTASKRES = DESCRIPTOR.message_types_by_name['GetTaskRes']
_TASKNOTIFYREQ = DESCRIPTOR.message_types_by_name['TaskNotifyReq']
_TASKNOTIFYRES = DESCRIPTOR.message_types_by_name['TaskNotifyRes']
_AIGCDEVICEBINDREQ = DESCRIPTOR.message_types_by_name['AigcDeviceBindReq']
_AIGCDEVICEBINDRES = DESCRIPTOR.message_types_by_name['AigcDeviceBindRes']
_AIGCDEVICEUNBINDREQ = DESCRIPTOR.message_types_by_name['AigcDeviceUnBindReq']
_AIGCDEVICEUNBINDRES = DESCRIPTOR.message_types_by_name['AigcDeviceUnBindRes']
_AIGCDEVICEINFOREQ = DESCRIPTOR.message_types_by_name['AigcDeviceInfoReq']
_AIGCDEVICEINFORES = DESCRIPTOR.message_types_by_name['AigcDeviceInfoRes']
_CREATEWIDGETREQ = DESCRIPTOR.message_types_by_name['CreateWidgetReq']
_CREATEWIDGETRES = DESCRIPTOR.message_types_by_name['CreateWidgetRes']
_UPLOADWIDGETURLREQ = DESCRIPTOR.message_types_by_name['UploadWidgetUrlReq']
_UPLOADWIDGETURLRES = DESCRIPTOR.message_types_by_name['UploadWidgetUrlRes']
_UPLOADWIDGETREQ = DESCRIPTOR.message_types_by_name['UploadWidgetReq']
_UPLOADWIDGETRES = DESCRIPTOR.message_types_by_name['UploadWidgetRes']
_UPLOADWIDGETCHECKREQ = DESCRIPTOR.message_types_by_name['UploadWidgetCheckReq']
_UPLOADWIDGETCHECKRES = DESCRIPTOR.message_types_by_name['UploadWidgetCheckRes']
_AIGCCREATEGROUPREQ = DESCRIPTOR.message_types_by_name['AigcCreateGroupReq']
_AIGCCREATEGROUPRES = DESCRIPTOR.message_types_by_name['AigcCreateGroupRes']
_AIGCREMOVEGROUPREQ = DESCRIPTOR.message_types_by_name['AigcRemoveGroupReq']
_AIGCREMOVEGROUPRES = DESCRIPTOR.message_types_by_name['AigcRemoveGroupRes']
_AIGCTASKRESULT = DESCRIPTOR.message_types_by_name['AigcTaskResult']
_AIGCDATA = DESCRIPTOR.message_types_by_name['AigcData']
_AIGCDATAEXTENSION = DESCRIPTOR.message_types_by_name['AigcDataExtension']
_UPLOADFILEURLREQ = DESCRIPTOR.message_types_by_name['UploadFileUrlReq']
_UPLOADFILEURLRES = DESCRIPTOR.message_types_by_name['UploadFileUrlRes']
TaskItem = _reflection.GeneratedProtocolMessageType('TaskItem', (_message.Message,), {
  'DESCRIPTOR' : _TASKITEM,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.TaskItem)
  })
_sym_db.RegisterMessage(TaskItem)

GetTaskReq = _reflection.GeneratedProtocolMessageType('GetTaskReq', (_message.Message,), {
  'DESCRIPTOR' : _GETTASKREQ,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.GetTaskReq)
  })
_sym_db.RegisterMessage(GetTaskReq)

GetTaskRes = _reflection.GeneratedProtocolMessageType('GetTaskRes', (_message.Message,), {
  'DESCRIPTOR' : _GETTASKRES,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.GetTaskRes)
  })
_sym_db.RegisterMessage(GetTaskRes)

TaskNotifyReq = _reflection.GeneratedProtocolMessageType('TaskNotifyReq', (_message.Message,), {
  'DESCRIPTOR' : _TASKNOTIFYREQ,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.TaskNotifyReq)
  })
_sym_db.RegisterMessage(TaskNotifyReq)

TaskNotifyRes = _reflection.GeneratedProtocolMessageType('TaskNotifyRes', (_message.Message,), {
  'DESCRIPTOR' : _TASKNOTIFYRES,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.TaskNotifyRes)
  })
_sym_db.RegisterMessage(TaskNotifyRes)

AigcDeviceBindReq = _reflection.GeneratedProtocolMessageType('AigcDeviceBindReq', (_message.Message,), {
  'DESCRIPTOR' : _AIGCDEVICEBINDREQ,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.AigcDeviceBindReq)
  })
_sym_db.RegisterMessage(AigcDeviceBindReq)

AigcDeviceBindRes = _reflection.GeneratedProtocolMessageType('AigcDeviceBindRes', (_message.Message,), {
  'DESCRIPTOR' : _AIGCDEVICEBINDRES,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.AigcDeviceBindRes)
  })
_sym_db.RegisterMessage(AigcDeviceBindRes)

AigcDeviceUnBindReq = _reflection.GeneratedProtocolMessageType('AigcDeviceUnBindReq', (_message.Message,), {
  'DESCRIPTOR' : _AIGCDEVICEUNBINDREQ,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.AigcDeviceUnBindReq)
  })
_sym_db.RegisterMessage(AigcDeviceUnBindReq)

AigcDeviceUnBindRes = _reflection.GeneratedProtocolMessageType('AigcDeviceUnBindRes', (_message.Message,), {
  'DESCRIPTOR' : _AIGCDEVICEUNBINDRES,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.AigcDeviceUnBindRes)
  })
_sym_db.RegisterMessage(AigcDeviceUnBindRes)

AigcDeviceInfoReq = _reflection.GeneratedProtocolMessageType('AigcDeviceInfoReq', (_message.Message,), {
  'DESCRIPTOR' : _AIGCDEVICEINFOREQ,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.AigcDeviceInfoReq)
  })
_sym_db.RegisterMessage(AigcDeviceInfoReq)

AigcDeviceInfoRes = _reflection.GeneratedProtocolMessageType('AigcDeviceInfoRes', (_message.Message,), {
  'DESCRIPTOR' : _AIGCDEVICEINFORES,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.AigcDeviceInfoRes)
  })
_sym_db.RegisterMessage(AigcDeviceInfoRes)

CreateWidgetReq = _reflection.GeneratedProtocolMessageType('CreateWidgetReq', (_message.Message,), {
  'DESCRIPTOR' : _CREATEWIDGETREQ,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.CreateWidgetReq)
  })
_sym_db.RegisterMessage(CreateWidgetReq)

CreateWidgetRes = _reflection.GeneratedProtocolMessageType('CreateWidgetRes', (_message.Message,), {
  'DESCRIPTOR' : _CREATEWIDGETRES,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.CreateWidgetRes)
  })
_sym_db.RegisterMessage(CreateWidgetRes)

UploadWidgetUrlReq = _reflection.GeneratedProtocolMessageType('UploadWidgetUrlReq', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADWIDGETURLREQ,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.UploadWidgetUrlReq)
  })
_sym_db.RegisterMessage(UploadWidgetUrlReq)

UploadWidgetUrlRes = _reflection.GeneratedProtocolMessageType('UploadWidgetUrlRes', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADWIDGETURLRES,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.UploadWidgetUrlRes)
  })
_sym_db.RegisterMessage(UploadWidgetUrlRes)

UploadWidgetReq = _reflection.GeneratedProtocolMessageType('UploadWidgetReq', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADWIDGETREQ,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.UploadWidgetReq)
  })
_sym_db.RegisterMessage(UploadWidgetReq)

UploadWidgetRes = _reflection.GeneratedProtocolMessageType('UploadWidgetRes', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADWIDGETRES,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.UploadWidgetRes)
  })
_sym_db.RegisterMessage(UploadWidgetRes)

UploadWidgetCheckReq = _reflection.GeneratedProtocolMessageType('UploadWidgetCheckReq', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADWIDGETCHECKREQ,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.UploadWidgetCheckReq)
  })
_sym_db.RegisterMessage(UploadWidgetCheckReq)

UploadWidgetCheckRes = _reflection.GeneratedProtocolMessageType('UploadWidgetCheckRes', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADWIDGETCHECKRES,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.UploadWidgetCheckRes)
  })
_sym_db.RegisterMessage(UploadWidgetCheckRes)

AigcCreateGroupReq = _reflection.GeneratedProtocolMessageType('AigcCreateGroupReq', (_message.Message,), {
  'DESCRIPTOR' : _AIGCCREATEGROUPREQ,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.AigcCreateGroupReq)
  })
_sym_db.RegisterMessage(AigcCreateGroupReq)

AigcCreateGroupRes = _reflection.GeneratedProtocolMessageType('AigcCreateGroupRes', (_message.Message,), {
  'DESCRIPTOR' : _AIGCCREATEGROUPRES,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.AigcCreateGroupRes)
  })
_sym_db.RegisterMessage(AigcCreateGroupRes)

AigcRemoveGroupReq = _reflection.GeneratedProtocolMessageType('AigcRemoveGroupReq', (_message.Message,), {
  'DESCRIPTOR' : _AIGCREMOVEGROUPREQ,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.AigcRemoveGroupReq)
  })
_sym_db.RegisterMessage(AigcRemoveGroupReq)

AigcRemoveGroupRes = _reflection.GeneratedProtocolMessageType('AigcRemoveGroupRes', (_message.Message,), {
  'DESCRIPTOR' : _AIGCREMOVEGROUPRES,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.AigcRemoveGroupRes)
  })
_sym_db.RegisterMessage(AigcRemoveGroupRes)

AigcTaskResult = _reflection.GeneratedProtocolMessageType('AigcTaskResult', (_message.Message,), {
  'DESCRIPTOR' : _AIGCTASKRESULT,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.AigcTaskResult)
  })
_sym_db.RegisterMessage(AigcTaskResult)

AigcData = _reflection.GeneratedProtocolMessageType('AigcData', (_message.Message,), {
  'DESCRIPTOR' : _AIGCDATA,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.AigcData)
  })
_sym_db.RegisterMessage(AigcData)

AigcDataExtension = _reflection.GeneratedProtocolMessageType('AigcDataExtension', (_message.Message,), {
  'DESCRIPTOR' : _AIGCDATAEXTENSION,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.AigcDataExtension)
  })
_sym_db.RegisterMessage(AigcDataExtension)

UploadFileUrlReq = _reflection.GeneratedProtocolMessageType('UploadFileUrlReq', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADFILEURLREQ,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.UploadFileUrlReq)
  })
_sym_db.RegisterMessage(UploadFileUrlReq)

UploadFileUrlRes = _reflection.GeneratedProtocolMessageType('UploadFileUrlRes', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADFILEURLRES,
  '__module__' : 'aigc_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.UploadFileUrlRes)
  })
_sym_db.RegisterMessage(UploadFileUrlRes)

_AIGCEXTOBJ = DESCRIPTOR.services_by_name['AigcExtObj']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\242\002\003PB3'
  _UPLOADWIDGETSTATUS._serialized_start=1852
  _UPLOADWIDGETSTATUS._serialized_end=1940
  _TASKITEM._serialized_start=40
  _TASKITEM._serialized_end=114
  _GETTASKREQ._serialized_start=116
  _GETTASKREQ._serialized_end=227
  _GETTASKRES._serialized_start=229
  _GETTASKRES._serialized_end=299
  _TASKNOTIFYREQ._serialized_start=301
  _TASKNOTIFYREQ._serialized_end=421
  _TASKNOTIFYRES._serialized_start=423
  _TASKNOTIFYRES._serialized_end=438
  _AIGCDEVICEBINDREQ._serialized_start=440
  _AIGCDEVICEBINDREQ._serialized_end=551
  _AIGCDEVICEBINDRES._serialized_start=553
  _AIGCDEVICEBINDRES._serialized_end=572
  _AIGCDEVICEUNBINDREQ._serialized_start=574
  _AIGCDEVICEUNBINDREQ._serialized_end=632
  _AIGCDEVICEUNBINDRES._serialized_start=634
  _AIGCDEVICEUNBINDRES._serialized_end=655
  _AIGCDEVICEINFOREQ._serialized_start=657
  _AIGCDEVICEINFOREQ._serialized_end=712
  _AIGCDEVICEINFORES._serialized_start=714
  _AIGCDEVICEINFORES._serialized_end=810
  _CREATEWIDGETREQ._serialized_start=812
  _CREATEWIDGETREQ._serialized_end=829
  _CREATEWIDGETRES._serialized_start=831
  _CREATEWIDGETRES._serialized_end=868
  _UPLOADWIDGETURLREQ._serialized_start=870
  _UPLOADWIDGETURLREQ._serialized_end=927
  _UPLOADWIDGETURLRES._serialized_start=929
  _UPLOADWIDGETURLRES._serialized_end=983
  _UPLOADWIDGETREQ._serialized_start=985
  _UPLOADWIDGETREQ._serialized_end=1036
  _UPLOADWIDGETRES._serialized_start=1038
  _UPLOADWIDGETRES._serialized_end=1072
  _UPLOADWIDGETCHECKREQ._serialized_start=1074
  _UPLOADWIDGETCHECKREQ._serialized_end=1130
  _UPLOADWIDGETCHECKRES._serialized_start=1132
  _UPLOADWIDGETCHECKRES._serialized_end=1214
  _AIGCCREATEGROUPREQ._serialized_start=1217
  _AIGCCREATEGROUPREQ._serialized_end=1353
  _AIGCCREATEGROUPRES._serialized_start=1355
  _AIGCCREATEGROUPRES._serialized_end=1401
  _AIGCREMOVEGROUPREQ._serialized_start=1403
  _AIGCREMOVEGROUPREQ._serialized_end=1489
  _AIGCREMOVEGROUPRES._serialized_start=1491
  _AIGCREMOVEGROUPRES._serialized_end=1511
  _AIGCTASKRESULT._serialized_start=1513
  _AIGCTASKRESULT._serialized_end=1557
  _AIGCDATA._serialized_start=1559
  _AIGCDATA._serialized_end=1642
  _AIGCDATAEXTENSION._serialized_start=1644
  _AIGCDATAEXTENSION._serialized_end=1727
  _UPLOADFILEURLREQ._serialized_start=1729
  _UPLOADFILEURLREQ._serialized_end=1796
  _UPLOADFILEURLRES._serialized_start=1798
  _UPLOADFILEURLRES._serialized_end=1850
  _AIGCEXTOBJ._serialized_start=1943
  _AIGCEXTOBJ._serialized_end=2550
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common_ext.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x63ommon_ext.proto\x12\x02pb\"\xf7\x02\n\x06Player\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x10\n\x08nickname\x18\x02 \x01(\t\x12\x18\n\x03sex\x18\x03 \x01(\x0e\x32\x0b.pb.SexType\x12\x0b\n\x03id2\x18\x04 \x01(\x03\x12\x0c\n\x04icon\x18\x05 \x01(\t\x12\r\n\x05\x66lags\x18\x06 \x01(\x03\x12\r\n\x05\x63harm\x18\x08 \x01(\x03\x12\x13\n\x0b\x63harm_level\x18\t \x01(\x05\x12\x14\n\x0cwealth_level\x18\n \x01(\x05\x12\x0e\n\x06wealth\x18\x0b \x01(\x03\x12\x12\n\nonline_exp\x18\x0c \x01(\r\x12\x11\n\tcreate_at\x18\r \x01(\r\x12\x11\n\tis_delete\x18\x0e \x01(\x08\x12\r\n\x05point\x18\x0f \x01(\x03\x12\x13\n\x0bpoint_level\x18\x10 \x01(\x05\x12\x11\n\tsignature\x18\x11 \x01(\t\x12\x0c\n\x04\x63ity\x18\x12 \x01(\t\x12\x10\n\x08\x62irthday\x18\x13 \x01(\t\x12\x14\n\x0conline_state\x18\x14 \x01(\x05\x12\x1a\n\x12NicknameUpdateTime\x18\x15 \x01(\r\"\x81\x01\n\x08UserInfo\x12\n\n\x02id\x18\x01 \x01(\x12\x12\x0c\n\x04\x63ity\x18\x02 \x01(\t\x12\x11\n\tsignature\x18\x03 \x01(\t\x12\x0c\n\x04mind\x18\x04 \x01(\t\x12\x10\n\x08\x62irthday\x18\x05 \x01(\t\x12\x15\n\rintimate_slot\x18\x06 \x01(\x11\x12\x11\n\tnameplate\x18\x07 \x01(\t\"\xd7\x02\n\nPlayerInfo\x12\x1a\n\x06player\x18\x01 \x01(\x0b\x32\n.pb.Player\x12\x1a\n\x06\x65\x66\x66\x65\x63t\x18\x02 \x03(\x0b\x32\n.pb.Effect\x12\x1a\n\x04\x63lan\x18\x03 \x01(\x0b\x32\x0c.pb.ClanInfo\x12\x10\n\x08\x66\x61ns_num\x18\x04 \x01(\x05\x12\x15\n\rfollowing_num\x18\x05 \x01(\x05\x12\x14\n\x0c\x66riend_alias\x18\x06 \x01(\t\x12\x1f\n\x07\x65\x66\x66\x65\x63ts\x18\x07 \x03(\x0b\x32\x0e.pb.EffectInfo\x12\x18\n\x10\x61ttitude_yes_num\x18\x08 \x01(\x03\x12\x17\n\x0ftotal_visit_num\x18\t \x01(\x03\x12\x15\n\radd_visit_num\x18\n \x01(\x03\x12\x1c\n\x05label\x18\x0b \x03(\x0b\x32\r.pb.LabelInfo\x12-\n\x0c\x64\x65grees_info\x18\x0c \x01(\x0b\x32\x17.pb.AttitudeDegreesInfo\"=\n\x07\x42\x61gItem\x12\x0f\n\x07gift_id\x18\x01 \x01(\r\x12\x0e\n\x06\x61mount\x18\x02 \x01(\r\x12\x11\n\tcteate_at\x18\x03 \x01(\t\"\"\n\x08\x41godaKey\x12\x16\n\x0epermission_key\x18\x01 \x01(\t\":\n\x0bOnOffStatus\x12\x0e\n\x06status\x18\x01 \x01(\x11\x12\x1b\n\x04type\x18\x02 \x01(\x0e\x32\r.pb.OnOffType\"\xf8\x01\n\x11SearchPlayerEntry\x12\n\n\x02id\x18\x01 \x01(\x12\x12\x0b\n\x03id2\x18\x02 \x01(\x12\x12\x10\n\x08nickname\x18\x03 \x01(\t\x12\x18\n\x03sex\x18\x04 \x01(\x0e\x32\x0b.pb.SexType\x12\x0c\n\x04icon\x18\x05 \x01(\t\x12\r\n\x05\x63harm\x18\x06 \x01(\x12\x12\x13\n\x0b\x63harm_level\x18\x07 \x01(\x11\x12\x0e\n\x06wealth\x18\x08 \x01(\x12\x12\x14\n\x0cwealth_level\x18\t \x01(\x11\x12\x0e\n\x06online\x18\n \x01(\x08\x12\x0f\n\x07room_id\x18\x0b \x01(\x12\x12\x12\n\nhas_passwd\x18\r \x01(\x08\x12\x11\n\tsignature\x18\x0e \x01(\t\"\x9f\x01\n\nEffectInfo\x12\n\n\x02id\x18\x01 \x01(\x03\x12%\n\ttime_type\x18\x02 \x01(\x0e\x32\x12.pb.EffectTimeType\x12\x10\n\x08\x65nd_time\x18\x03 \x01(\x03\x12\'\n\nuse_status\x18\x04 \x01(\x0e\x32\x13.pb.EffectUseStatus\x12#\n\x0b\x65\x66\x66\x65\x63t_type\x18\x05 \x01(\x0e\x32\x0e.pb.EffectType\"\xaf\x01\n\x06\x45\x66\x66\x65\x63t\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04\x66lag\x18\x02 \x01(\x05\x12\x0b\n\x03str\x18\x03 \x01(\t\x12%\n\ttime_type\x18\x04 \x01(\x0e\x32\x12.pb.EffectTimeType\x12\x10\n\x08\x65nd_time\x18\x05 \x01(\x05\x12\'\n\nuse_status\x18\x06 \x01(\x0e\x32\x13.pb.EffectUseStatus\x12\x1c\n\x04type\x18\x07 \x01(\x0e\x32\x0e.pb.EffectType\"T\n\x0c\x45\x66\x66\x65\x63tConfig\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x1c\n\x04type\x18\x02 \x01(\x0e\x32\x0e.pb.EffectType\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\x0c\"6\n\x15\x45\x66\x66\x65\x63tNicknamePendant\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x10\n\x08show_url\x18\x02 \x01(\t\"G\n\rEffectSerConf\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x1c\n\x04type\x18\x02 \x01(\x0e\x32\x0e.pb.EffectType\x12\x0c\n\x04name\x18\x03 \x01(\t\"0\n\rIndexTipRooms\x12\x0f\n\x07room_id\x18\x01 \x01(\x03\x12\x0e\n\x06tip_id\x18\x02 \x01(\x05\"=\n\x07RegisId\x12\x0b\n\x03ios\x18\x01 \x01(\t\x12\x0f\n\x07\x61ndroid\x18\x02 \x01(\t\x12\x14\n\x0cmanufacturer\x18\x03 \x01(\t\"P\n\nModelOnOff\x12\x1c\n\x05onOff\x18\x01 \x01(\x0e\x32\r.pb.OnOffType\x12$\n\x06status\x18\x02 \x01(\x0e\x32\x14.pb.ModelOnOffStatus\"\xd0\x01\n\x04Rank\x12\n\n\x02id\x18\x01 \x01(\x12\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x18\n\x03sex\x18\x03 \x01(\x0e\x32\x0b.pb.SexType\x12\r\n\x05level\x18\x04 \x01(\r\x12\r\n\x05value\x18\x05 \x01(\x04\x12\x10\n\x08res_time\x18\x06 \x01(\r\x12\x0f\n\x07gap_val\x18\x07 \x01(\r\x12\x0c\n\x04icon\x18\x08 \x01(\t\x12\x0f\n\x07gift_id\x18\t \x01(\x04\x12\x10\n\x08gift_num\x18\n \x01(\r\x12\x0f\n\x07ranking\x18\x0b \x01(\r\x12\x11\n\tgift_name\x18\x0c \x01(\t\"5\n\x0fPlayerChairRoom\x12\x11\n\tplayer_id\x18\x01 \x01(\x03\x12\x0f\n\x07room_id\x18\x02 \x01(\x03\"l\n\x08\x43lanInfo\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x11\n\ticon_word\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\r\n\x05level\x18\x04 \x01(\x03\x12\x12\n\nlevel_name\x18\x05 \x01(\t\x12\x10\n\x08is_admin\x18\x06 \x01(\x08\"*\n\x06Period\x12\x10\n\x08\x62\x65gin_at\x18\x01 \x01(\x03\x12\x0e\n\x06\x65nd_at\x18\x02 \x01(\x03\",\n\tLabelInfo\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x13\n\x0b\x63lassify_id\x18\x02 \x01(\x05\"Y\n\x13PlayerResourceShort\x12-\n\rresource_type\x18\x01 \x01(\x0e\x32\x16.pb.PlayerResourceType\x12\x13\n\x0bresource_id\x18\x02 \x01(\t\"\x96\x01\n\x0ePlayerResource\x12-\n\rresource_type\x18\x01 \x01(\x0e\x32\x16.pb.PlayerResourceType\x12\x13\n\x0bresource_id\x18\x02 \x01(\t\x12\x10\n\x08nickname\x18\x03 \x01(\t\x12\x14\n\x0chead_img_url\x18\x04 \x01(\t\x12\x18\n\x03sex\x18\x05 \x01(\x0e\x32\x0b.pb.SexType\"c\n\x17PlayerResourceWithScore\x12+\n\x0fplayer_resource\x18\x01 \x01(\x0b\x32\x12.pb.PlayerResource\x12\r\n\x05score\x18\x02 \x01(\x03\x12\x0c\n\x04rank\x18\x03 \x01(\x05\"\xb4\x01\n\x13\x41ttitudeDegreesInfo\x12\x35\n\x0e\x64\x65grees_status\x18\x01 \x01(\x0e\x32\x1d.pb.AttitudeDegreesStatusType\x12\x36\n\rcategory_info\x18\x02 \x03(\x0b\x32\x1f.pb.AttitudeCategoryDegreesInfo\x12\x14\n\x0ctotal_degree\x18\x03 \x01(\x05\x12\x18\n\x10\x61nalysis_content\x18\x04 \x01(\t\"g\n\x1b\x41ttitudeCategoryDegreesInfo\x12\x13\n\x0b\x63\x61tegory_id\x18\x01 \x01(\x05\x12\x15\n\rcategory_name\x18\x02 \x01(\t\x12\x0e\n\x06\x64\x65gree\x18\x03 \x01(\x05\x12\x0c\n\x04icon\x18\x04 \x01(\t\"\x85\x01\n\x0e\x43MediaResource\x12\"\n\nmedia_type\x18\x01 \x01(\x0e\x32\x0e.pb.CMediaType\x12\x11\n\tmedia_url\x18\x02 \x01(\t\x12\x11\n\tcover_url\x18\x03 \x01(\t\x12\x13\n\x0bmedia_width\x18\x04 \x01(\x05\x12\x14\n\x0cmedia_height\x18\x05 \x01(\x05\"\x1b\n\x0bSayHelloReq\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x1c\n\x0bSayHelloRes\x12\r\n\x05reply\x18\x01 \x01(\t\"b\n\x0cHeartbeatReq\x12\x0f\n\x07goim_id\x18\x01 \x01(\x03\x12\x11\n\tplayer_id\x18\x02 \x01(\x03\x12\n\n\x02ip\x18\x03 \x01(\t\x12\"\n\ndeviceType\x18\x04 \x01(\x0e\x32\x0e.pb.DeviceType\"!\n\x0cHeartbeatRes\x12\x11\n\ttimestamp\x18\x02 \x01(\x03*\xad\x01\n\tCommonErr\x12\x0f\n\x0b\x45rrCodeNone\x10\x00\x12\x11\n\x0c\x45rrCodeRedis\x10\x91N\x12\x11\n\x0c\x45rrCodeMysql\x10\x92N\x12\x15\n\x10\x45rrCodeFrequency\x10\x93N\x12\x11\n\x0c\x45rrCodeParam\x10\x94N\x12\x16\n\x11\x45rrCodeNoMatchObj\x10\x95N\x12\x10\n\x0b\x45rrCodeBusy\x10\x96N\x12\x15\n\x0f\x45rrCodeMaintain\x10\x9a\x82\x01*,\n\x07SexType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04MALE\x10\x01\x12\n\n\x06\x46\x45MALE\x10\x02*0\n\x0bOwnerInRoom\x12\x11\n\rNotInSelfRoom\x10\x00\x12\x0e\n\nInSelfRoom\x10\x01*%\n\tSceneType\x12\x0b\n\x07ST_ZERO\x10\x00\x12\x0b\n\x07ST_HOME\x10\x01*y\n\rRoomAdminType\x12\r\n\tRAT_GUEST\x10\x00\x12\x0e\n\nRAT_NORMAL\x10\n\x12\r\n\tRAT_ADMIN\x10\x14\x12\r\n\tRAT_OWNER\x10\x1e\x12\x13\n\x0fRAT_SUPER_ADMIN\x10(\x12\x16\n\tRAT_BLACK\x10\xfb\xff\xff\xff\xff\xff\xff\xff\xff\x01*\xfb\x01\n\nDeviceType\x12\x0e\n\nDT_UNKNOWN\x10\x00\x12\x12\n\x0e\x44T_FLASHPLAYER\x10\x01\x12\x14\n\x10\x44T_ANDROID_PHONE\x10\x14\x12\x10\n\x0c\x44T_IOS_PHONE\x10(\x12\x18\n\x14\x44T_WINDOWS_ASSISTANT\x10P\x12\x11\n\rDT_WINDOWS_PC\x10Z\x12\x0c\n\x08\x44T_ROBOT\x10\x64\x12\x1a\n\x16\x44T_WECHAT_SUBSCRIPTION\x10n\x12\x17\n\x13\x44T_QQ_SMALL_PROGRAM\x10x\x12\x17\n\x12\x44T_WX_MINI_PROGRAM\x10\x82\x01\x12\x0b\n\x06\x44T_WEB\x10\x8c\x01\x12\x0b\n\x06\x44T_MAC\x10\x96\x01*\x99\x01\n\x0bPlayerFlags\x12\x0b\n\x07PF_ZERO\x10\x00\x12\x14\n\x10PF_CERTIFICATION\x10\x01\x12\x10\n\x0cPF_BIND_BANK\x10\x04\x12\r\n\tPF_INVITE\x10\x05\x12\x13\n\x0fPF_CHARGE_FIRST\x10\x0c\x12\x18\n\x14PF_ATTITUDE_QUESTION\x10\r\x12\x17\n\x13PF_END_REGISTRATION\x10\x0e*2\n\x0c\x41\x63\x63ountFlags\x12\x0b\n\x07\x41\x46_ZERO\x10\x00\x12\x15\n\x11\x41\x46_PHONE_VERIFIED\x10\x01*\xfc\r\n\tOnOffType\x12\x0c\n\x08YEAR_BAG\x10\x00\x12\r\n\tCRACK_EGG\x10\x01\x12\x0e\n\nGOOGLE_PAY\x10\x05\x12\x0b\n\x07IAP_PAY\x10\x06\x12\n\n\x06INVITE\x10\x07\x12\x12\n\x0eINDEX_CATEGORY\x10\x08\x12\n\n\x06\x43\x45RTIF\x10\t\x12\t\n\x05GUARD\x10\n\x12\x10\n\x0cLOTTERY_DRAW\x10\x0c\x12\x0f\n\x0bMENTOR_SHIP\x10\r\x12\x0e\n\nCERTIF_IOS\x10\x0e\x12\x11\n\rREAL_IDENTITY\x10\x0f\x12\x0f\n\x0bNOVICE_GIFT\x10\x10\x12\x12\n\x0eROOM_SET_MODEL\x10\x12\x12\x11\n\rACTIVITY_TYPE\x10\x14\x12\x0c\n\x08\x41\x43TIVITY\x10\x15\x12\x0c\n\x08HOT_SONG\x10\x17\x12\x0e\n\nROOM_ENTER\x10\"\x12\x1d\n\x19ROOM_PATTERN_HIGH_QUALITY\x10#\x12\x11\n\rAUTH_LOGIN_UI\x10&\x12\x12\n\x0eUSER_DATA_EDIT\x10)\x12\x11\n\rCERTIFICATION\x10+\x12\x1b\n\x17\x43\x45RTIFICATION_ROOM_SHOW\x10,\x12%\n!CERTIFICATION_ROOM_WIN_OPEN_CLOSE\x10-\x12\x10\n\x0c\x43\x45RTIFY_WORD\x10.\x12\x11\n\rCERTIFY_CHAIR\x10/\x12\x1c\n\x18\x43\x45RTIFY_UPDATE_USER_INFO\x10\x30\x12\x1c\n\x18\x43\x45RTIFY_BROADCAST_FRIEND\x10\x31\x12\x15\n\x11\x43\x45RTIFY_HEAD_LINE\x10\x32\x12\x15\n\x11\x43\x45RTIFY_TIAO_TIAO\x10\x33\x12\x14\n\x10LOGIN_BIND_PHONE\x10\x34\x12\x1c\n\x18\x43\x45RTIFY_OWNER_ENTER_ROOM\x10\x35\x12\x0f\n\x0bYoung_Model\x10:\x12\x14\n\x10\x43USTOMER_SERVICE\x10;\x12\x15\n\x11OVERSEAS_IP_LIMIT\x10\x42\x12\x12\n\x0eOLD_NAME_LIMIT\x10\x43\x12\x12\n\x0e\x43RACK_SELF_MSG\x10\x44\x12\x12\n\x0eORDER_LOCATION\x10G\x12\x12\n\x0e\x44\x45LETE_ACCOUNT\x10I\x12\x0f\n\x0bYUNPIAN_SMS\x10J\x12\x11\n\rBIND_PHONE_V2\x10K\x12\x14\n\x10\x42IND_PHONE_LOGIN\x10L\x12\x0e\n\nCOUNT_DOWN\x10N\x12\x0e\n\nOXYGEN_BAR\x10^\x12\x13\n\x0fPRIVACY_SETTING\x10_\x12\x1f\n\x1bOXYGEN_BAR_CLAN_MEMBER_ONLY\x10`\x12\x18\n\x14OXYGEN_BAR_TREND_GIF\x10\x61\x12\x0e\n\nDATA_AUDIT\x10\x62\x12\r\n\tInner_Tec\x10\x64\x12\r\n\tInner_Ali\x10\x65\x12\x16\n\x12\x43\x45RTIFY_IM_PICTURE\x10g\x12\x0b\n\x07\x43MB_VIP\x10h\x12\x13\n\x0f\x43RACKEGG_FOREST\x10i\x12\x13\n\x0e\x41NTI_ADDICTION\x10\xc8\x01\x12&\n!TEXT_FILTER_ROOM_SCREEN_ENCRYPTED\x10\xc9\x01\x12(\n#TEXT_FILTER_ROOM_SCREEN_UNENCRYPTED\x10\xca\x01\x12!\n\x1cTEXT_FILTER_BROADCAST_FRIEND\x10\xcb\x01\x12\x1d\n\x18TEXT_FILTER_PRIVATE_CHAT\x10\xcc\x01\x12\x10\n\x0c\x42\x43_HEAD_LINE\x10n\x12\x13\n\x0fONE_CLICK_LOGIN\x10o\x12\x0e\n\nCERTIFY_PM\x10p\x12\x13\n\x0f\x43\x45RTIFY_PICTURE\x10q\x12\x19\n\x15\x43HANNEL_ADVERT_AUDITS\x10r\x12\x1a\n\x16\x43\x45RTIFY_CREATE_CHANNEL\x10t\x12\x18\n\x14\x43\x45RTIFY_JOIN_CHANNEL\x10u\x12\x10\n\x0c\x43\x45RTIFY_GIVE\x10v\x12\x17\n\x13\x43\x45RTIFY_ROOM_NOTICE\x10w\x12\x14\n\x10\x43\x45RTIFY_RECHARGE\x10x\x12\x19\n\x15\x43\x45RTIFY_PUBLISH_TREND\x10y\x12\x19\n\x15\x43\x45RTIFY_COMMENT_TREND\x10z\x12\x11\n\rHOME_NAV_TYPE\x10{\x12\x11\n\rLOGIN_CHECKED\x10|\x12\x0e\n\nHIGH_SOUND\x10}\x12\x16\n\x12HIGH_SOUND_CHANNEL\x10~\x12\x1a\n\x16\x43HANNEL_STAR_CHALLENGE\x10\x7f\x12\x11\n\x0c\x43HANNEL_STAT\x10\x80\x01\x12\x11\n\x0cREGISTER_SEX\x10\x82\x01\x12\x16\n\x11REGISTER_NICKNAME\x10\x83\x01\x12\x16\n\x11REGISTER_ATTITUDE\x10\x84\x01\x12\x13\n\x0e\x43REATE_CHANNEL\x10\x85\x01\x12\x1a\n\x15\x43OMMUNITY_TREND_AUDIO\x10\x86\x01\x12\x0c\n\x07IM_TIPS\x10\x87\x01\x12\x18\n\x13MULTI_CLIENT_ONLINE\x10\xfd\x01*)\n\nStatusCode\x12\x0b\n\x07SC_FAIL\x10\x00\x12\x0e\n\nSC_SUCCESS\x10\x01*?\n\nEffectType\x12\x12\n\x0e\x45\x66\x66\x65\x63tTypeNone\x10\x00\x12\x1d\n\x19\x45\x66\x66\x65\x63tTypeNicknamePendant\x10\x01*\x7f\n\x0e\x45\x66\x66\x65\x63tTimeType\x12\x18\n\x14\x45\x66\x66\x65\x63tTimeTypeAlways\x10\x00\x12\x16\n\x12\x45\x66\x66\x65\x63tTimeTypeMike\x10\x01\x12\x1e\n\x1a\x45\x66\x66\x65\x63tTimeTypeWearInPacket\x10\x02\x12\x1b\n\x17\x45\x66\x66\x65\x63tTimeTypePermanent\x10\x03*,\n\x0f\x45\x66\x66\x65\x63tUseStatus\x12\n\n\x06\x45S_Use\x10\x00\x12\r\n\tES_NotUse\x10\x01*I\n\x10\x45\x66\x66\x65\x63tNoticeType\x12\x18\n\x14\x45\x66\x66\x65\x63tNoticeTypeGain\x10\x00\x12\x1b\n\x17\x45\x66\x66\x65\x63tNoticeTypeTimeout\x10\x01*:\n\x10ModelOnOffStatus\x12\x0b\n\x07\x41LL_OFF\x10\x00\x12\n\n\x06\x41LL_ON\x10\x01\x12\r\n\tWHITELIST\x10\x02*A\n\x08RankType\x12\x0b\n\x07RT_ZERO\x10\x00\x12\x0c\n\x08RT_CHARM\x10\x01\x12\r\n\tRT_WEALTH\x10\x02\x12\x0b\n\x07RT_GIFT\x10\x03*N\n\rLoadClickType\x12\x0c\n\x08LCT_ZERO\x10\x00\x12\x17\n\x13LCT_INTIMATE_DETAIL\x10\x01\x12\x16\n\x12LCT_INTIMATE_STORE\x10\x02*F\n\x0b\x41uditStatus\x12\x11\n\rAS_Audit_Pass\x10\x00\x12\x0f\n\x0b\x41S_Auditing\x10\x01\x12\x13\n\x0f\x41S_Audit_Refuse\x10\x02*\xf3\x01\n\nUploadType\x12\x0c\n\x08TypeZero\x10\x00\x12\x10\n\x0cHeadAlbumImg\x10\x01\x12\x0f\n\x0bHeadIconImg\x10\x02\x12\x0f\n\x0b\x44ynamicsImg\x10\x03\x12\r\n\tClientLog\x10\x04\x12\x0e\n\nTipOffsImg\x10\x05\x12\x0c\n\x08Indetity\x10\x06\x12\x0b\n\x07PMMedia\x10\x07\x12\t\n\x05Voice\x10\x08\x12\x11\n\rBackgroundImg\x10\x17\x12\x0f\n\x0b\x43hannelIcon\x10\x18\x12\x11\n\rWXRobotQRcode\x10\x19\x12\x13\n\x0f\x43ommunityTagImg\x10\x1c\x12\x12\n\x0ePersonLabelImg\x10\x1d*\xe9\x01\n\x0ePayChannelType\x12\x0c\n\x08PCT_NULL\x10\x00\x12\x11\n\rPCT_ALIPAY_H5\x10\x02\x12\x12\n\x0ePCT_ALIPAY_APP\x10\x03\x12\x11\n\rPCT_WXPAY_APP\x10\x04\x12\x10\n\x0cPCT_WXPAY_H5\x10\x05\x12\x0b\n\x07PCT_IAP\x10\x06\x12\x0c\n\x08PCT_PLAY\x10\x08\x12\x0e\n\nPCT_PAYPAL\x10\n\x12\r\n\tPCT_BOING\x10\x0b\x12\x10\n\x0cPCT_UNIONPAY\x10\x0c\x12\x0e\n\tPCT_AGENT\x10\xfd\x01\x12\x0f\n\nPCT_MANUAL\x10\xfe\x01\x12\x10\n\x0bPCT_DEVTEST\x10\xff\x01*i\n\x04Role\x12\n\n\x06R_NONE\x10\x00\x12\x0f\n\x0bR_SUPERUSER\x10\x01\x12\x08\n\x04R_OW\x10\x02\x12\x08\n\x04R_VP\x10\x03\x12\x08\n\x04R_MA\x10\x04\x12\t\n\x05R_CA1\x10\x05\x12\t\n\x05R_CA2\x10\x06\x12\x07\n\x03R_R\x10\x07\x12\x07\n\x03R_U\x10\x08*]\n\x0eNameplateStyle\x12\x0b\n\x07NS_NONE\x10\x00\x12\x0e\n\nNS_STYLE_1\x10\x01\x12\x0e\n\nNS_STYLE_2\x10\x02\x12\x0e\n\nNS_STYLE_3\x10\x03\x12\x0e\n\nNS_STYLE_4\x10\x04*E\n\x12PlayerResourceType\x12\x0c\n\x08PRT_NONE\x10\x00\x12\x15\n\x11PRT_FIRST_ACCOUNT\x10\x01\x12\n\n\x06PRT_WX\x10\x02*f\n\x19\x41ttitudeDegreesStatusType\x12\x13\n\x0f\x41\x44ST_BOTH_EVERY\x10\x00\x12\x17\n\x13\x41\x44ST_OPPOSITE_EVERY\x10\x01\x12\x1b\n\x17\x41\x44ST_OPPOSITE_NOTENOUGH\x10\x02*u\n\nCMediaType\x12\x13\n\x0f\x43MediaType_None\x10\x00\x12\x12\n\x0e\x43MediaType_Png\x10\x01\x12\x12\n\x0e\x43MediaType_Gif\x10\x02\x12\x14\n\x10\x43MediaType_Video\x10\x03\x12\x14\n\x10\x43MediaType_Audio\x10\x04*w\n\x11\x44\x65viceConnectOper\x12\x0c\n\x08\x44\x43S_None\x10\x00\x12\x12\n\x0e\x44\x43S_Requesting\x10\x01\x12\x0f\n\x0b\x44\x43S_Receive\x10\x02\x12\x0e\n\nDCS_Refuse\x10\x03\x12\x0f\n\x0b\x44\x43S_Timeout\x10\x04\x12\x0e\n\nDCS_Cancel\x10\x05*\xa7\x01\n\x0b\x44\x65viceCmdId\x12\x11\n\rDC_DeviceZero\x10\x00\x12\x14\n\x0e\x44\x43_DeviceLogin\x10\x99\x98\x1f\x12\x1e\n\x18\x44\x43_MessageConnectOperate\x10\x9a\x98\x1f\x12\x1c\n\x16\x44\x43_MessageStatusUpdate\x10\x9b\x98\x1f\x12\x1a\n\x14\x44\x43_DeviceShareStatus\x10\x9c\x98\x1f\x12\x15\n\x0f\x44\x43_SingoConnect\x10\xb9\xa5%*L\n\nTaskStatus\x12\x0b\n\x07TS_None\x10\x00\x12\x11\n\rTS_Processing\x10\x01\x12\x0e\n\nTS_Success\x10\x02\x12\x0e\n\nTS_Failure\x10\x03*N\n\x08TaskType\x12\x0b\n\x07TT_None\x10\x00\x12\x0c\n\x08TT_Image\x10\x01\x12\x0c\n\x08TT_Video\x10\x02\x12\x0c\n\x08TT_Audio\x10\x03\x12\x0b\n\x07TT_Text\x10\x04*C\n\tLabelType\x12\x0b\n\x07LT_NONE\x10\x00\x12\x0b\n\x07LT_POST\x10\x01\x12\x0e\n\nLT_Gallery\x10\x02\x12\x0c\n\x08LT_Group\x10\x03*N\n\x08\x41igcType\x12\x0b\n\x07\x41T_NONE\x10\x00\x12\x0c\n\x08\x41T_IMAGE\x10\x01\x12\x0c\n\x08\x41T_VIDEO\x10\x02\x12\x0c\n\x08\x41T_AUDIO\x10\x03\x12\x0b\n\x07\x41T_TEXT\x10\x04\x42\x06\xa2\x02\x03PB3b\x06proto3')

_COMMONERR = DESCRIPTOR.enum_types_by_name['CommonErr']
CommonErr = enum_type_wrapper.EnumTypeWrapper(_COMMONERR)
_SEXTYPE = DESCRIPTOR.enum_types_by_name['SexType']
SexType = enum_type_wrapper.EnumTypeWrapper(_SEXTYPE)
_OWNERINROOM = DESCRIPTOR.enum_types_by_name['OwnerInRoom']
OwnerInRoom = enum_type_wrapper.EnumTypeWrapper(_OWNERINROOM)
_SCENETYPE = DESCRIPTOR.enum_types_by_name['SceneType']
SceneType = enum_type_wrapper.EnumTypeWrapper(_SCENETYPE)
_ROOMADMINTYPE = DESCRIPTOR.enum_types_by_name['RoomAdminType']
RoomAdminType = enum_type_wrapper.EnumTypeWrapper(_ROOMADMINTYPE)
_DEVICETYPE = DESCRIPTOR.enum_types_by_name['DeviceType']
DeviceType = enum_type_wrapper.EnumTypeWrapper(_DEVICETYPE)
_PLAYERFLAGS = DESCRIPTOR.enum_types_by_name['PlayerFlags']
PlayerFlags = enum_type_wrapper.EnumTypeWrapper(_PLAYERFLAGS)
_ACCOUNTFLAGS = DESCRIPTOR.enum_types_by_name['AccountFlags']
AccountFlags = enum_type_wrapper.EnumTypeWrapper(_ACCOUNTFLAGS)
_ONOFFTYPE = DESCRIPTOR.enum_types_by_name['OnOffType']
OnOffType = enum_type_wrapper.EnumTypeWrapper(_ONOFFTYPE)
_STATUSCODE = DESCRIPTOR.enum_types_by_name['StatusCode']
StatusCode = enum_type_wrapper.EnumTypeWrapper(_STATUSCODE)
_EFFECTTYPE = DESCRIPTOR.enum_types_by_name['EffectType']
EffectType = enum_type_wrapper.EnumTypeWrapper(_EFFECTTYPE)
_EFFECTTIMETYPE = DESCRIPTOR.enum_types_by_name['EffectTimeType']
EffectTimeType = enum_type_wrapper.EnumTypeWrapper(_EFFECTTIMETYPE)
_EFFECTUSESTATUS = DESCRIPTOR.enum_types_by_name['EffectUseStatus']
EffectUseStatus = enum_type_wrapper.EnumTypeWrapper(_EFFECTUSESTATUS)
_EFFECTNOTICETYPE = DESCRIPTOR.enum_types_by_name['EffectNoticeType']
EffectNoticeType = enum_type_wrapper.EnumTypeWrapper(_EFFECTNOTICETYPE)
_MODELONOFFSTATUS = DESCRIPTOR.enum_types_by_name['ModelOnOffStatus']
ModelOnOffStatus = enum_type_wrapper.EnumTypeWrapper(_MODELONOFFSTATUS)
_RANKTYPE = DESCRIPTOR.enum_types_by_name['RankType']
RankType = enum_type_wrapper.EnumTypeWrapper(_RANKTYPE)
_LOADCLICKTYPE = DESCRIPTOR.enum_types_by_name['LoadClickType']
LoadClickType = enum_type_wrapper.EnumTypeWrapper(_LOADCLICKTYPE)
_AUDITSTATUS = DESCRIPTOR.enum_types_by_name['AuditStatus']
AuditStatus = enum_type_wrapper.EnumTypeWrapper(_AUDITSTATUS)
_UPLOADTYPE = DESCRIPTOR.enum_types_by_name['UploadType']
UploadType = enum_type_wrapper.EnumTypeWrapper(_UPLOADTYPE)
_PAYCHANNELTYPE = DESCRIPTOR.enum_types_by_name['PayChannelType']
PayChannelType = enum_type_wrapper.EnumTypeWrapper(_PAYCHANNELTYPE)
_ROLE = DESCRIPTOR.enum_types_by_name['Role']
Role = enum_type_wrapper.EnumTypeWrapper(_ROLE)
_NAMEPLATESTYLE = DESCRIPTOR.enum_types_by_name['NameplateStyle']
NameplateStyle = enum_type_wrapper.EnumTypeWrapper(_NAMEPLATESTYLE)
_PLAYERRESOURCETYPE = DESCRIPTOR.enum_types_by_name['PlayerResourceType']
PlayerResourceType = enum_type_wrapper.EnumTypeWrapper(_PLAYERRESOURCETYPE)
_ATTITUDEDEGREESSTATUSTYPE = DESCRIPTOR.enum_types_by_name['AttitudeDegreesStatusType']
AttitudeDegreesStatusType = enum_type_wrapper.EnumTypeWrapper(_ATTITUDEDEGREESSTATUSTYPE)
_CMEDIATYPE = DESCRIPTOR.enum_types_by_name['CMediaType']
CMediaType = enum_type_wrapper.EnumTypeWrapper(_CMEDIATYPE)
_DEVICECONNECTOPER = DESCRIPTOR.enum_types_by_name['DeviceConnectOper']
DeviceConnectOper = enum_type_wrapper.EnumTypeWrapper(_DEVICECONNECTOPER)
_DEVICECMDID = DESCRIPTOR.enum_types_by_name['DeviceCmdId']
DeviceCmdId = enum_type_wrapper.EnumTypeWrapper(_DEVICECMDID)
_TASKSTATUS = DESCRIPTOR.enum_types_by_name['TaskStatus']
TaskStatus = enum_type_wrapper.EnumTypeWrapper(_TASKSTATUS)
_TASKTYPE = DESCRIPTOR.enum_types_by_name['TaskType']
TaskType = enum_type_wrapper.EnumTypeWrapper(_TASKTYPE)
_LABELTYPE = DESCRIPTOR.enum_types_by_name['LabelType']
LabelType = enum_type_wrapper.EnumTypeWrapper(_LABELTYPE)
_AIGCTYPE = DESCRIPTOR.enum_types_by_name['AigcType']
AigcType = enum_type_wrapper.EnumTypeWrapper(_AIGCTYPE)
ErrCodeNone = 0
ErrCodeRedis = 10001
ErrCodeMysql = 10002
ErrCodeFrequency = 10003
ErrCodeParam = 10004
ErrCodeNoMatchObj = 10005
ErrCodeBusy = 10006
ErrCodeMaintain = 16666
UNKNOWN = 0
MALE = 1
FEMALE = 2
NotInSelfRoom = 0
InSelfRoom = 1
ST_ZERO = 0
ST_HOME = 1
RAT_GUEST = 0
RAT_NORMAL = 10
RAT_ADMIN = 20
RAT_OWNER = 30
RAT_SUPER_ADMIN = 40
RAT_BLACK = -5
DT_UNKNOWN = 0
DT_FLASHPLAYER = 1
DT_ANDROID_PHONE = 20
DT_IOS_PHONE = 40
DT_WINDOWS_ASSISTANT = 80
DT_WINDOWS_PC = 90
DT_ROBOT = 100
DT_WECHAT_SUBSCRIPTION = 110
DT_QQ_SMALL_PROGRAM = 120
DT_WX_MINI_PROGRAM = 130
DT_WEB = 140
DT_MAC = 150
PF_ZERO = 0
PF_CERTIFICATION = 1
PF_BIND_BANK = 4
PF_INVITE = 5
PF_CHARGE_FIRST = 12
PF_ATTITUDE_QUESTION = 13
PF_END_REGISTRATION = 14
AF_ZERO = 0
AF_PHONE_VERIFIED = 1
YEAR_BAG = 0
CRACK_EGG = 1
GOOGLE_PAY = 5
IAP_PAY = 6
INVITE = 7
INDEX_CATEGORY = 8
CERTIF = 9
GUARD = 10
LOTTERY_DRAW = 12
MENTOR_SHIP = 13
CERTIF_IOS = 14
REAL_IDENTITY = 15
NOVICE_GIFT = 16
ROOM_SET_MODEL = 18
ACTIVITY_TYPE = 20
ACTIVITY = 21
HOT_SONG = 23
ROOM_ENTER = 34
ROOM_PATTERN_HIGH_QUALITY = 35
AUTH_LOGIN_UI = 38
USER_DATA_EDIT = 41
CERTIFICATION = 43
CERTIFICATION_ROOM_SHOW = 44
CERTIFICATION_ROOM_WIN_OPEN_CLOSE = 45
CERTIFY_WORD = 46
CERTIFY_CHAIR = 47
CERTIFY_UPDATE_USER_INFO = 48
CERTIFY_BROADCAST_FRIEND = 49
CERTIFY_HEAD_LINE = 50
CERTIFY_TIAO_TIAO = 51
LOGIN_BIND_PHONE = 52
CERTIFY_OWNER_ENTER_ROOM = 53
Young_Model = 58
CUSTOMER_SERVICE = 59
OVERSEAS_IP_LIMIT = 66
OLD_NAME_LIMIT = 67
CRACK_SELF_MSG = 68
ORDER_LOCATION = 71
DELETE_ACCOUNT = 73
YUNPIAN_SMS = 74
BIND_PHONE_V2 = 75
BIND_PHONE_LOGIN = 76
COUNT_DOWN = 78
OXYGEN_BAR = 94
PRIVACY_SETTING = 95
OXYGEN_BAR_CLAN_MEMBER_ONLY = 96
OXYGEN_BAR_TREND_GIF = 97
DATA_AUDIT = 98
Inner_Tec = 100
Inner_Ali = 101
CERTIFY_IM_PICTURE = 103
CMB_VIP = 104
CRACKEGG_FOREST = 105
ANTI_ADDICTION = 200
TEXT_FILTER_ROOM_SCREEN_ENCRYPTED = 201
TEXT_FILTER_ROOM_SCREEN_UNENCRYPTED = 202
TEXT_FILTER_BROADCAST_FRIEND = 203
TEXT_FILTER_PRIVATE_CHAT = 204
BC_HEAD_LINE = 110
ONE_CLICK_LOGIN = 111
CERTIFY_PM = 112
CERTIFY_PICTURE = 113
CHANNEL_ADVERT_AUDITS = 114
CERTIFY_CREATE_CHANNEL = 116
CERTIFY_JOIN_CHANNEL = 117
CERTIFY_GIVE = 118
CERTIFY_ROOM_NOTICE = 119
CERTIFY_RECHARGE = 120
CERTIFY_PUBLISH_TREND = 121
CERTIFY_COMMENT_TREND = 122
HOME_NAV_TYPE = 123
LOGIN_CHECKED = 124
HIGH_SOUND = 125
HIGH_SOUND_CHANNEL = 126
CHANNEL_STAR_CHALLENGE = 127
CHANNEL_STAT = 128
REGISTER_SEX = 130
REGISTER_NICKNAME = 131
REGISTER_ATTITUDE = 132
CREATE_CHANNEL = 133
COMMUNITY_TREND_AUDIO = 134
IM_TIPS = 135
MULTI_CLIENT_ONLINE = 253
SC_FAIL = 0
SC_SUCCESS = 1
EffectTypeNone = 0
EffectTypeNicknamePendant = 1
EffectTimeTypeAlways = 0
EffectTimeTypeMike = 1
EffectTimeTypeWearInPacket = 2
EffectTimeTypePermanent = 3
ES_Use = 0
ES_NotUse = 1
EffectNoticeTypeGain = 0
EffectNoticeTypeTimeout = 1
ALL_OFF = 0
ALL_ON = 1
WHITELIST = 2
RT_ZERO = 0
RT_CHARM = 1
RT_WEALTH = 2
RT_GIFT = 3
LCT_ZERO = 0
LCT_INTIMATE_DETAIL = 1
LCT_INTIMATE_STORE = 2
AS_Audit_Pass = 0
AS_Auditing = 1
AS_Audit_Refuse = 2
TypeZero = 0
HeadAlbumImg = 1
HeadIconImg = 2
DynamicsImg = 3
ClientLog = 4
TipOffsImg = 5
Indetity = 6
PMMedia = 7
Voice = 8
BackgroundImg = 23
ChannelIcon = 24
WXRobotQRcode = 25
CommunityTagImg = 28
PersonLabelImg = 29
PCT_NULL = 0
PCT_ALIPAY_H5 = 2
PCT_ALIPAY_APP = 3
PCT_WXPAY_APP = 4
PCT_WXPAY_H5 = 5
PCT_IAP = 6
PCT_PLAY = 8
PCT_PAYPAL = 10
PCT_BOING = 11
PCT_UNIONPAY = 12
PCT_AGENT = 253
PCT_MANUAL = 254
PCT_DEVTEST = 255
R_NONE = 0
R_SUPERUSER = 1
R_OW = 2
R_VP = 3
R_MA = 4
R_CA1 = 5
R_CA2 = 6
R_R = 7
R_U = 8
NS_NONE = 0
NS_STYLE_1 = 1
NS_STYLE_2 = 2
NS_STYLE_3 = 3
NS_STYLE_4 = 4
PRT_NONE = 0
PRT_FIRST_ACCOUNT = 1
PRT_WX = 2
ADST_BOTH_EVERY = 0
ADST_OPPOSITE_EVERY = 1
ADST_OPPOSITE_NOTENOUGH = 2
CMediaType_None = 0
CMediaType_Png = 1
CMediaType_Gif = 2
CMediaType_Video = 3
CMediaType_Audio = 4
DCS_None = 0
DCS_Requesting = 1
DCS_Receive = 2
DCS_Refuse = 3
DCS_Timeout = 4
DCS_Cancel = 5
DC_DeviceZero = 0
DC_DeviceLogin = 511001
DC_MessageConnectOperate = 511002
DC_MessageStatusUpdate = 511003
DC_DeviceShareStatus = 511004
DC_SingoConnect = 611001
TS_None = 0
TS_Processing = 1
TS_Success = 2
TS_Failure = 3
TT_None = 0
TT_Image = 1
TT_Video = 2
TT_Audio = 3
TT_Text = 4
LT_NONE = 0
LT_POST = 1
LT_Gallery = 2
LT_Group = 3
AT_NONE = 0
AT_IMAGE = 1
AT_VIDEO = 2
AT_AUDIO = 3
AT_TEXT = 4


_PLAYER = DESCRIPTOR.message_types_by_name['Player']
_USERINFO = DESCRIPTOR.message_types_by_name['UserInfo']
_PLAYERINFO = DESCRIPTOR.message_types_by_name['PlayerInfo']
_BAGITEM = DESCRIPTOR.message_types_by_name['BagItem']
_AGODAKEY = DESCRIPTOR.message_types_by_name['AgodaKey']
_ONOFFSTATUS = DESCRIPTOR.message_types_by_name['OnOffStatus']
_SEARCHPLAYERENTRY = DESCRIPTOR.message_types_by_name['SearchPlayerEntry']
_EFFECTINFO = DESCRIPTOR.message_types_by_name['EffectInfo']
_EFFECT = DESCRIPTOR.message_types_by_name['Effect']
_EFFECTCONFIG = DESCRIPTOR.message_types_by_name['EffectConfig']
_EFFECTNICKNAMEPENDANT = DESCRIPTOR.message_types_by_name['EffectNicknamePendant']
_EFFECTSERCONF = DESCRIPTOR.message_types_by_name['EffectSerConf']
_INDEXTIPROOMS = DESCRIPTOR.message_types_by_name['IndexTipRooms']
_REGISID = DESCRIPTOR.message_types_by_name['RegisId']
_MODELONOFF = DESCRIPTOR.message_types_by_name['ModelOnOff']
_RANK = DESCRIPTOR.message_types_by_name['Rank']
_PLAYERCHAIRROOM = DESCRIPTOR.message_types_by_name['PlayerChairRoom']
_CLANINFO = DESCRIPTOR.message_types_by_name['ClanInfo']
_PERIOD = DESCRIPTOR.message_types_by_name['Period']
_LABELINFO = DESCRIPTOR.message_types_by_name['LabelInfo']
_PLAYERRESOURCESHORT = DESCRIPTOR.message_types_by_name['PlayerResourceShort']
_PLAYERRESOURCE = DESCRIPTOR.message_types_by_name['PlayerResource']
_PLAYERRESOURCEWITHSCORE = DESCRIPTOR.message_types_by_name['PlayerResourceWithScore']
_ATTITUDEDEGREESINFO = DESCRIPTOR.message_types_by_name['AttitudeDegreesInfo']
_ATTITUDECATEGORYDEGREESINFO = DESCRIPTOR.message_types_by_name['AttitudeCategoryDegreesInfo']
_CMEDIARESOURCE = DESCRIPTOR.message_types_by_name['CMediaResource']
_SAYHELLOREQ = DESCRIPTOR.message_types_by_name['SayHelloReq']
_SAYHELLORES = DESCRIPTOR.message_types_by_name['SayHelloRes']
_HEARTBEATREQ = DESCRIPTOR.message_types_by_name['HeartbeatReq']
_HEARTBEATRES = DESCRIPTOR.message_types_by_name['HeartbeatRes']
Player = _reflection.GeneratedProtocolMessageType('Player', (_message.Message,), {
  'DESCRIPTOR' : _PLAYER,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.Player)
  })
_sym_db.RegisterMessage(Player)

UserInfo = _reflection.GeneratedProtocolMessageType('UserInfo', (_message.Message,), {
  'DESCRIPTOR' : _USERINFO,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.UserInfo)
  })
_sym_db.RegisterMessage(UserInfo)

PlayerInfo = _reflection.GeneratedProtocolMessageType('PlayerInfo', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERINFO,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.PlayerInfo)
  })
_sym_db.RegisterMessage(PlayerInfo)

BagItem = _reflection.GeneratedProtocolMessageType('BagItem', (_message.Message,), {
  'DESCRIPTOR' : _BAGITEM,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.BagItem)
  })
_sym_db.RegisterMessage(BagItem)

AgodaKey = _reflection.GeneratedProtocolMessageType('AgodaKey', (_message.Message,), {
  'DESCRIPTOR' : _AGODAKEY,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.AgodaKey)
  })
_sym_db.RegisterMessage(AgodaKey)

OnOffStatus = _reflection.GeneratedProtocolMessageType('OnOffStatus', (_message.Message,), {
  'DESCRIPTOR' : _ONOFFSTATUS,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.OnOffStatus)
  })
_sym_db.RegisterMessage(OnOffStatus)

SearchPlayerEntry = _reflection.GeneratedProtocolMessageType('SearchPlayerEntry', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHPLAYERENTRY,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.SearchPlayerEntry)
  })
_sym_db.RegisterMessage(SearchPlayerEntry)

EffectInfo = _reflection.GeneratedProtocolMessageType('EffectInfo', (_message.Message,), {
  'DESCRIPTOR' : _EFFECTINFO,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.EffectInfo)
  })
_sym_db.RegisterMessage(EffectInfo)

Effect = _reflection.GeneratedProtocolMessageType('Effect', (_message.Message,), {
  'DESCRIPTOR' : _EFFECT,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.Effect)
  })
_sym_db.RegisterMessage(Effect)

EffectConfig = _reflection.GeneratedProtocolMessageType('EffectConfig', (_message.Message,), {
  'DESCRIPTOR' : _EFFECTCONFIG,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.EffectConfig)
  })
_sym_db.RegisterMessage(EffectConfig)

EffectNicknamePendant = _reflection.GeneratedProtocolMessageType('EffectNicknamePendant', (_message.Message,), {
  'DESCRIPTOR' : _EFFECTNICKNAMEPENDANT,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.EffectNicknamePendant)
  })
_sym_db.RegisterMessage(EffectNicknamePendant)

EffectSerConf = _reflection.GeneratedProtocolMessageType('EffectSerConf', (_message.Message,), {
  'DESCRIPTOR' : _EFFECTSERCONF,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.EffectSerConf)
  })
_sym_db.RegisterMessage(EffectSerConf)

IndexTipRooms = _reflection.GeneratedProtocolMessageType('IndexTipRooms', (_message.Message,), {
  'DESCRIPTOR' : _INDEXTIPROOMS,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.IndexTipRooms)
  })
_sym_db.RegisterMessage(IndexTipRooms)

RegisId = _reflection.GeneratedProtocolMessageType('RegisId', (_message.Message,), {
  'DESCRIPTOR' : _REGISID,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.RegisId)
  })
_sym_db.RegisterMessage(RegisId)

ModelOnOff = _reflection.GeneratedProtocolMessageType('ModelOnOff', (_message.Message,), {
  'DESCRIPTOR' : _MODELONOFF,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.ModelOnOff)
  })
_sym_db.RegisterMessage(ModelOnOff)

Rank = _reflection.GeneratedProtocolMessageType('Rank', (_message.Message,), {
  'DESCRIPTOR' : _RANK,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.Rank)
  })
_sym_db.RegisterMessage(Rank)

PlayerChairRoom = _reflection.GeneratedProtocolMessageType('PlayerChairRoom', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERCHAIRROOM,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.PlayerChairRoom)
  })
_sym_db.RegisterMessage(PlayerChairRoom)

ClanInfo = _reflection.GeneratedProtocolMessageType('ClanInfo', (_message.Message,), {
  'DESCRIPTOR' : _CLANINFO,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.ClanInfo)
  })
_sym_db.RegisterMessage(ClanInfo)

Period = _reflection.GeneratedProtocolMessageType('Period', (_message.Message,), {
  'DESCRIPTOR' : _PERIOD,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.Period)
  })
_sym_db.RegisterMessage(Period)

LabelInfo = _reflection.GeneratedProtocolMessageType('LabelInfo', (_message.Message,), {
  'DESCRIPTOR' : _LABELINFO,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.LabelInfo)
  })
_sym_db.RegisterMessage(LabelInfo)

PlayerResourceShort = _reflection.GeneratedProtocolMessageType('PlayerResourceShort', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERRESOURCESHORT,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.PlayerResourceShort)
  })
_sym_db.RegisterMessage(PlayerResourceShort)

PlayerResource = _reflection.GeneratedProtocolMessageType('PlayerResource', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERRESOURCE,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.PlayerResource)
  })
_sym_db.RegisterMessage(PlayerResource)

PlayerResourceWithScore = _reflection.GeneratedProtocolMessageType('PlayerResourceWithScore', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERRESOURCEWITHSCORE,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.PlayerResourceWithScore)
  })
_sym_db.RegisterMessage(PlayerResourceWithScore)

AttitudeDegreesInfo = _reflection.GeneratedProtocolMessageType('AttitudeDegreesInfo', (_message.Message,), {
  'DESCRIPTOR' : _ATTITUDEDEGREESINFO,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.AttitudeDegreesInfo)
  })
_sym_db.RegisterMessage(AttitudeDegreesInfo)

AttitudeCategoryDegreesInfo = _reflection.GeneratedProtocolMessageType('AttitudeCategoryDegreesInfo', (_message.Message,), {
  'DESCRIPTOR' : _ATTITUDECATEGORYDEGREESINFO,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.AttitudeCategoryDegreesInfo)
  })
_sym_db.RegisterMessage(AttitudeCategoryDegreesInfo)

CMediaResource = _reflection.GeneratedProtocolMessageType('CMediaResource', (_message.Message,), {
  'DESCRIPTOR' : _CMEDIARESOURCE,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.CMediaResource)
  })
_sym_db.RegisterMessage(CMediaResource)

SayHelloReq = _reflection.GeneratedProtocolMessageType('SayHelloReq', (_message.Message,), {
  'DESCRIPTOR' : _SAYHELLOREQ,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.SayHelloReq)
  })
_sym_db.RegisterMessage(SayHelloReq)

SayHelloRes = _reflection.GeneratedProtocolMessageType('SayHelloRes', (_message.Message,), {
  'DESCRIPTOR' : _SAYHELLORES,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.SayHelloRes)
  })
_sym_db.RegisterMessage(SayHelloRes)

HeartbeatReq = _reflection.GeneratedProtocolMessageType('HeartbeatReq', (_message.Message,), {
  'DESCRIPTOR' : _HEARTBEATREQ,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.HeartbeatReq)
  })
_sym_db.RegisterMessage(HeartbeatReq)

HeartbeatRes = _reflection.GeneratedProtocolMessageType('HeartbeatRes', (_message.Message,), {
  'DESCRIPTOR' : _HEARTBEATRES,
  '__module__' : 'common_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.HeartbeatRes)
  })
_sym_db.RegisterMessage(HeartbeatRes)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\242\002\003PB3'
  _COMMONERR._serialized_start=3470
  _COMMONERR._serialized_end=3643
  _SEXTYPE._serialized_start=3645
  _SEXTYPE._serialized_end=3689
  _OWNERINROOM._serialized_start=3691
  _OWNERINROOM._serialized_end=3739
  _SCENETYPE._serialized_start=3741
  _SCENETYPE._serialized_end=3778
  _ROOMADMINTYPE._serialized_start=3780
  _ROOMADMINTYPE._serialized_end=3901
  _DEVICETYPE._serialized_start=3904
  _DEVICETYPE._serialized_end=4155
  _PLAYERFLAGS._serialized_start=4158
  _PLAYERFLAGS._serialized_end=4311
  _ACCOUNTFLAGS._serialized_start=4313
  _ACCOUNTFLAGS._serialized_end=4363
  _ONOFFTYPE._serialized_start=4366
  _ONOFFTYPE._serialized_end=6154
  _STATUSCODE._serialized_start=6156
  _STATUSCODE._serialized_end=6197
  _EFFECTTYPE._serialized_start=6199
  _EFFECTTYPE._serialized_end=6262
  _EFFECTTIMETYPE._serialized_start=6264
  _EFFECTTIMETYPE._serialized_end=6391
  _EFFECTUSESTATUS._serialized_start=6393
  _EFFECTUSESTATUS._serialized_end=6437
  _EFFECTNOTICETYPE._serialized_start=6439
  _EFFECTNOTICETYPE._serialized_end=6512
  _MODELONOFFSTATUS._serialized_start=6514
  _MODELONOFFSTATUS._serialized_end=6572
  _RANKTYPE._serialized_start=6574
  _RANKTYPE._serialized_end=6639
  _LOADCLICKTYPE._serialized_start=6641
  _LOADCLICKTYPE._serialized_end=6719
  _AUDITSTATUS._serialized_start=6721
  _AUDITSTATUS._serialized_end=6791
  _UPLOADTYPE._serialized_start=6794
  _UPLOADTYPE._serialized_end=7037
  _PAYCHANNELTYPE._serialized_start=7040
  _PAYCHANNELTYPE._serialized_end=7273
  _ROLE._serialized_start=7275
  _ROLE._serialized_end=7380
  _NAMEPLATESTYLE._serialized_start=7382
  _NAMEPLATESTYLE._serialized_end=7475
  _PLAYERRESOURCETYPE._serialized_start=7477
  _PLAYERRESOURCETYPE._serialized_end=7546
  _ATTITUDEDEGREESSTATUSTYPE._serialized_start=7548
  _ATTITUDEDEGREESSTATUSTYPE._serialized_end=7650
  _CMEDIATYPE._serialized_start=7652
  _CMEDIATYPE._serialized_end=7769
  _DEVICECONNECTOPER._serialized_start=7771
  _DEVICECONNECTOPER._serialized_end=7890
  _DEVICECMDID._serialized_start=7893
  _DEVICECMDID._serialized_end=8060
  _TASKSTATUS._serialized_start=8062
  _TASKSTATUS._serialized_end=8138
  _TASKTYPE._serialized_start=8140
  _TASKTYPE._serialized_end=8218
  _LABELTYPE._serialized_start=8220
  _LABELTYPE._serialized_end=8287
  _AIGCTYPE._serialized_start=8289
  _AIGCTYPE._serialized_end=8367
  _PLAYER._serialized_start=25
  _PLAYER._serialized_end=400
  _USERINFO._serialized_start=403
  _USERINFO._serialized_end=532
  _PLAYERINFO._serialized_start=535
  _PLAYERINFO._serialized_end=878
  _BAGITEM._serialized_start=880
  _BAGITEM._serialized_end=941
  _AGODAKEY._serialized_start=943
  _AGODAKEY._serialized_end=977
  _ONOFFSTATUS._serialized_start=979
  _ONOFFSTATUS._serialized_end=1037
  _SEARCHPLAYERENTRY._serialized_start=1040
  _SEARCHPLAYERENTRY._serialized_end=1288
  _EFFECTINFO._serialized_start=1291
  _EFFECTINFO._serialized_end=1450
  _EFFECT._serialized_start=1453
  _EFFECT._serialized_end=1628
  _EFFECTCONFIG._serialized_start=1630
  _EFFECTCONFIG._serialized_end=1714
  _EFFECTNICKNAMEPENDANT._serialized_start=1716
  _EFFECTNICKNAMEPENDANT._serialized_end=1770
  _EFFECTSERCONF._serialized_start=1772
  _EFFECTSERCONF._serialized_end=1843
  _INDEXTIPROOMS._serialized_start=1845
  _INDEXTIPROOMS._serialized_end=1893
  _REGISID._serialized_start=1895
  _REGISID._serialized_end=1956
  _MODELONOFF._serialized_start=1958
  _MODELONOFF._serialized_end=2038
  _RANK._serialized_start=2041
  _RANK._serialized_end=2249
  _PLAYERCHAIRROOM._serialized_start=2251
  _PLAYERCHAIRROOM._serialized_end=2304
  _CLANINFO._serialized_start=2306
  _CLANINFO._serialized_end=2414
  _PERIOD._serialized_start=2416
  _PERIOD._serialized_end=2458
  _LABELINFO._serialized_start=2460
  _LABELINFO._serialized_end=2504
  _PLAYERRESOURCESHORT._serialized_start=2506
  _PLAYERRESOURCESHORT._serialized_end=2595
  _PLAYERRESOURCE._serialized_start=2598
  _PLAYERRESOURCE._serialized_end=2748
  _PLAYERRESOURCEWITHSCORE._serialized_start=2750
  _PLAYERRESOURCEWITHSCORE._serialized_end=2849
  _ATTITUDEDEGREESINFO._serialized_start=2852
  _ATTITUDEDEGREESINFO._serialized_end=3032
  _ATTITUDECATEGORYDEGREESINFO._serialized_start=3034
  _ATTITUDECATEGORYDEGREESINFO._serialized_end=3137
  _CMEDIARESOURCE._serialized_start=3140
  _CMEDIARESOURCE._serialized_end=3273
  _SAYHELLOREQ._serialized_start=3275
  _SAYHELLOREQ._serialized_end=3302
  _SAYHELLORES._serialized_start=3304
  _SAYHELLORES._serialized_end=3332
  _HEARTBEATREQ._serialized_start=3334
  _HEARTBEATREQ._serialized_end=3432
  _HEARTBEATRES._serialized_start=3434
  _HEARTBEATRES._serialized_end=3467
# @@protoc_insertion_point(module_scope)



import json
import sys

resultDic = {
    "result" : [ 
    ],
    "status" : 0,           #0 is success
    "message" : ""
}

## 输入data参数, JSON格式如下: 
#   {
#      "task_id": [task_id],                    #任务id
#      "widget_id": [widget_id],                #组件id
#      "pending_count": [pending_count],        #待处理任务数
#      "fn_name": "test",
#      "param": {
#          "text":"Hello World"
#      }
#   }
def runTask(data):
    #write program in here
    demoReturnText = "hello world"
    
    resultDic["result"].append({
        "type" : "text",
        "content": [ 
            demoReturnText
        ],
        "extension" : {
            "info": "",
            "cover_url": ""
        }
    })
    return resultDic



import os
import sys
import time
import signal
import subprocess
import json
from pathlib import Path
from urllib.parse import *

from mecord import xy_socket
from mecord import store
from mecord import xy_pb
from mecord import xy_user 
from mecord import utils

class BaseService:
    def __init__(self, name, pid_file=None):
        self.name = name
        self.pid_file = pid_file
        self.running = False
        self.halt = False

    def start(self):
        store.writeDeviceInfo(utils.deviceInfo())
        self.halt = False
        if self.pid_file:
            with open(self.pid_file, 'w') as f:
                f.write(str(os.getpid()))
        self.running = True
        signal.signal(signal.SIGTERM, self.stop)
        self.run()

    def run(self):
        pass

    def stop(self, signum=None, frame=None):
        self.running = False
        if self.pid_file and os.path.exists(self.pid_file):
            os.remove(self.pid_file)

    def restart(self):
        self.stop()
        time.sleep(1)
        self.start()

    def is_running(self):
        if self.pid_file and os.path.exists(self.pid_file):
            with open(self.pid_file, 'r') as f:
                pid = int(f.read())
                try:
                    os.kill(pid, 0)
                except OSError:
                    return False
                else:
                    return True
        else:
            return self.running

class MecordService(BaseService):
    def __init__(self):
        pid_file = '/var/run/MecordService.pid' if sys.platform != 'win32' else None
        super().__init__("MecordService", pid_file)
        # self.socket = MecordSocket(self.receiveData)
        # self.socket.start()

    def receiveData(self, s):
        print(s)

    def executeLocalPython(self, taskUUID, cmd, param):
        inputArgs = os.path.join(os.path.dirname(os.path.abspath(__file__)), f"{taskUUID}.in")
        if os.path.exists(inputArgs):
            os.remove(inputArgs)
        with open(inputArgs, 'w') as f:
            json.dump(param, f)
        outArgs = os.path.join(os.path.dirname(os.path.abspath(__file__)), f"{taskUUID}.out")
        if os.path.exists(outArgs):
            os.remove(outArgs)
            
        command = f'{sys.executable} "{cmd}" --run "{inputArgs}" --out "{outArgs}"'
        result = subprocess.run(command, stdout=subprocess.PIPE,
                                stderr=subprocess.PIPE, shell=True)
        print(result.stdout.decode(encoding="utf8", errors="ignore"))
        outData = {}
        executeSuccess = False
        if os.path.exists(outArgs):
            with open(outArgs, 'r') as f:
                outData = json.load(f)
            executeSuccess = True
        else:
            print(f"task {taskUUID} result is empty!, please check {cmd}")

        if os.path.exists(inputArgs):
            os.remove(inputArgs)
        if os.path.exists(outArgs):
            os.remove(outArgs)
        return executeSuccess, outData

    def hasValue(self, data, type, key):
        if "type" not in data:
            print("result is not avalid")
        if data["type"] == type and "extension" in data and key in data["extension"] and len(data["extension"][key]) > 0:
            return True
        return False
             
    def checkResult(self, data):
        for it in data["result"]:
            if self.hasValue(it, "text", "cover_url") == False:
                it["extension"]["cover_url"] = ""
            if self.hasValue(it, "audio", "cover_url") == False:
               it["extension"]["cover_url"] = ""
               
            if "extension" in it and "cover_url" in it["extension"] and len(it["extension"]["cover_url"]) > 0:
                w, h = utils.getOssImageSize(it["extension"]["cover_url"])
                if w > 0 and h > 0:
                    if "?" in str(it["extension"]["cover_url"]):
                        it["extension"]["cover_url"] += f"&width={w}&height={h}"
                    else:
                        it["extension"]["cover_url"] = urljoin(it["extension"]["cover_url"], f"?width={w}&height={h}")


    def cmdWithWidget(self, widget_id):
        map = store.widgetMap()
        if widget_id in map and len(map[widget_id]) > 0:
            return map[widget_id]
        return None

    def run(self):
        try:
            while self.running:
                datas = xy_pb.GetTask(store.token())
                for it in datas:
                    taskUUID = it["taskUUID"]
                    pending_count = it["pending_count"]
                    config = json.loads(it["config"])
                    params = json.loads(it["data"])
                    widget_id = config["widget_id"]
                    group_id = config["group_id"]
                    #cmd
                    local_cmd = self.cmdWithWidget(widget_id)
                    cmd = ""
                    if local_cmd:
                        cmd = local_cmd
                    else:
                        cmd = str(Path(config["cmd"]))
                    #params
                    params["task_id"] = taskUUID
                    params["pending_count"] = pending_count
                    #run
                    executeSuccess, result_obj = self.executeLocalPython(taskUUID, cmd, params)
                    #result
                    is_ok = executeSuccess or result_obj["status"] == 0
                    msg = "Unknow Error"
                    if executeSuccess and len(msg) > 0:
                        msg = result_obj["message"]
                    if is_ok:
                        self.checkResult(result_obj)
                    if xy_pb.TaskNotify(taskUUID, 
                                is_ok, 
                                msg, 
                                json.dumps(result_obj["result"], separators=(',', ':'))):
                        if is_ok:
                            print(f"task : {taskUUID} complete success")
                        else:
                            print(f"task : {taskUUID} fail")
                
                time.sleep(1)
        except Exception as e:
            print(e)
            return

    def status_ok(self):
        service_running = super()._is_running()
        socket_running = True #self.socket.isRunning()
        is_login =xy_user.User().isLogin()
        return socket_running and service_running and is_login
    

#python xxxxxx\main.py --run "{\"task_id\":1,\"widget_id\":1,\"pending_count\":1,\"fn_name\":\"test\",\"param\":{\"text\":\"Hello World\"}}"
# MecordService.executeLocalPython(None, "asdasdlasasdasdasdas", r"E:\mecord_sd\3333333333333333333333\script\main.py", {"task_id":1,"widget_id":1,"pending_count":1,"fn_name":"test","param":{"text":"Hello World"}})


import requests
import os
from urllib.parse import *

from mecord import ftp_upload
from mecord import xy_pb
from pathlib import Path

def upload(src):
    file_name = Path(src).name
    ossurl, content_type = xy_pb.GetOssUrl(os.path.splitext(file_name)[-1][1:])
    if len(ossurl) == 0:
        print("oss server is not avalid")
        return ""

    headers = dict()
    headers['Content-Type'] = content_type
    res = requests.put(ossurl, data=open(src, 'rb').read(), headers=headers)
    if res.status_code == 200:
        realOssUrl = urljoin(ossurl, "?s")
        return realOssUrl
    else:
        print(f"upload file fail! res = {res}")
        return ""

def uploadWidget(src, widgetid):
    ossurl, content_type = xy_pb.GetWidgetOssUrl(widgetid)
    if len(ossurl) == 0:
        print("oss server is not avalid")
        return "", -1
    
    headers = dict()
    headers['Content-Type'] = content_type
    res = requests.put(ossurl, data=open(src, 'rb').read(), headers=headers)
    if res.status_code == 200:
        realOssUrl = urljoin(ossurl, "?s")
        checkid = xy_pb.WidgetUploadEnd(realOssUrl)
        if checkid > 0:
            return realOssUrl, checkid
        else:
            return "", -1
    else:
        print(f"upload file fail! res = {res}")
        return "", -1

# print(urljoin("http://yesdesktop-web-beta.oss-cn-shenzhen.aliyuncs.com/uploads/aigc/widgets/9475cb02-becb-45de-8656-ebe0204201b2/9475cb02-becb-45de-8656-ebe0204201b2.zip?Expires=1678705199&OSSAccessKeyId=LTAI5tGmTwAZJEzGL38wAjXV&Signature=uDvQJUs83WQ1ZU9dbMcHTw6zuDQ=", "?s"))
# print(upload("E:\\aigc\\mecord_python\\publish_mecord_pip.zip", "application/zip"))
# print(uploadWidget("E:\\aigc\\mecord_python\\publish_mecord_pip.zip", "fac64812-23c1-4a37-8e99-ddc4fb4d2a01"))


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: user_status_ext.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from mecord import common_ext_pb2 as common__ext__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15user_status_ext.proto\x12\x02pb\x1a\x10\x63ommon_ext.proto\"a\n\x08LoginReq\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\"\n\ndeviceType\x18\x02 \x01(\x0e\x32\x0e.pb.DeviceType\x12\x10\n\x08\x64\x65viceId\x18\x03 \x01(\t\x12\x12\n\npush_token\x18\x04 \x01(\t\"\x1e\n\x08LoginRes\x12\x12\n\naccount_id\x18\x01 \x01(\x12\"_\n\x10\x42roadcastRelogin\x12\x10\n\x08\x64\x65viceId\x18\x01 \x01(\t\x12#\n\x0b\x64\x65vice_type\x18\x02 \x01(\x0e\x32\x0e.pb.DeviceType\x12\x14\n\x0cmulti_client\x18\x03 \x01(\x08\"5\n\x12\x42roadcastTakeLeave\x12\x12\n\naccount_id\x18\x01 \x01(\x12\x12\x0b\n\x03msg\x18\x02 \x01(\t\"\x7f\n\x1b\x42roadcastDeviceDisconnected\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12#\n\x0b\x64\x65vice_type\x18\x02 \x01(\x0e\x32\x0e.pb.DeviceType\x12(\n\x06reason\x18\x03 \x01(\x0e\x32\x18.pb.DisconnectReasonType\"?\n\tLogoutReq\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x11\n\taccountId\x18\x02 \x01(\x03\x12\x12\n\ndeviceCode\x18\x03 \x01(\x03\"\x0b\n\tLogoutRes\"/\n\rDisconnectReq\x12\x0e\n\x06\x63onnId\x18\x01 \x01(\x12\x12\x0e\n\x06userId\x18\x02 \x01(\x12\"\x0f\n\rDisconnectRes\"\x14\n\x12UserConInfoListReq\"3\n\x12UserConInfoListRes\x12\x1d\n\x04list\x18\x01 \x03(\x0b\x32\x0f.pb.UserConInfo\"\x97\x01\n\x0bUserConInfo\x12\n\n\x02id\x18\x01 \x01(\x12\x12\n\n\x02ip\x18\x02 \x01(\t\x12#\n\x0b\x64\x65vice_type\x18\x03 \x01(\x0e\x32\x0e.pb.DeviceType\x12\x11\n\tdevice_id\x18\x04 \x01(\t\x12\x10\n\x08\x64ie_time\x18\x05 \x01(\x12\x12\x11\n\tplayer_id\x18\x06 \x01(\x12\x12\x13\n\x0b\x63reate_time\x18\x07 \x01(\x12\"S\n\x19UserDeviceDisconnectedReq\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12#\n\x0b\x64\x65vice_type\x18\x02 \x01(\x0e\x32\x0e.pb.DeviceType\"\x1b\n\x19UserDeviceDisconnectedRes\"f\n\x1bNotifyDeviceDisconnectedReq\x12\x10\n\x08phone_no\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12&\n\x04type\x18\x03 \x01(\x0e\x32\x18.pb.DisconnectReasonType\"\x1d\n\x1bNotifyDeviceDisconnectedRes*\xdc\x01\n\rUserStatusErr\x12\x15\n\x11UserStatusSUCCESS\x10\x00\x12\x1d\n\x17\x45rrUserStatusKeyExpired\x10\x89\xa1\x02\x12\x1d\n\x17\x45rrUserStatusBanAccount\x10\x8a\xa1\x02\x12\x18\n\x12\x45rrUserStatusBanIp\x10\x8b\xa1\x02\x12\x1a\n\x14\x45rrUserStatusRelogin\x10\x8c\xa1\x02\x12\x1c\n\x16\x45rrUserStatusTakeLeave\x10\x8d\xa1\x02\x12\"\n\x1c\x45rrUserStatusAccountDeleting\x10\x92\xa1\x02*\x89\x01\n\x0fUserStatusCmdId\x12\x15\n\x11UC_UserStatusZero\x10\x00\x12\x1a\n\x14UC_UserStatusRelogin\x10\x89\xca\x1e\x12\x1c\n\x16UC_UserStatusTakeLeave\x10\x8a\xca\x1e\x12%\n\x1fUC_UserStatusDeviceDisconnected\x10\x8b\xca\x1e*\x98\x01\n\x14\x44isconnectReasonType\x12\x0c\n\x08\x44RT_None\x10\x00\x12\x14\n\x10\x44RT_RefreshState\x10\x01\x12\x14\n\x10\x44RT_RemoveDevice\x10\x02\x12\x0b\n\x07\x44RT_Ban\x10\x03\x12\x12\n\x0e\x44RT_DelAccount\x10\x04\x12\x11\n\rDRT_ResetPass\x10\x05\x12\x12\n\x0e\x44RT_ModifyPass\x10\x06\x32\xc6\x03\n\x10UserStatusExtObj\x12#\n\x05Login\x12\x0c.pb.LoginReq\x1a\x0c.pb.LoginRes\x12&\n\x06Logout\x12\r.pb.LogoutReq\x1a\r.pb.LogoutRes\x12\x38\n\x10NotifyDisConnect\x12\x11.pb.DisconnectReq\x1a\x11.pb.DisconnectRes\x12/\n\tHeartbeat\x12\x10.pb.HeartbeatReq\x1a\x10.pb.HeartbeatRes\x12\x41\n\x0fUserConInfoList\x12\x16.pb.UserConInfoListReq\x1a\x16.pb.UserConInfoListRes\x12V\n\x16UserDeviceDisconnected\x12\x1d.pb.UserDeviceDisconnectedReq\x1a\x1d.pb.UserDeviceDisconnectedRes\x12_\n\x1bGetNotifyDeviceDisconnected\x12\x1f.pb.NotifyDeviceDisconnectedReq\x1a\x1f.pb.NotifyDeviceDisconnectedResB\x06\xa2\x02\x03PB3b\x06proto3')

_USERSTATUSERR = DESCRIPTOR.enum_types_by_name['UserStatusErr']
UserStatusErr = enum_type_wrapper.EnumTypeWrapper(_USERSTATUSERR)
_USERSTATUSCMDID = DESCRIPTOR.enum_types_by_name['UserStatusCmdId']
UserStatusCmdId = enum_type_wrapper.EnumTypeWrapper(_USERSTATUSCMDID)
_DISCONNECTREASONTYPE = DESCRIPTOR.enum_types_by_name['DisconnectReasonType']
DisconnectReasonType = enum_type_wrapper.EnumTypeWrapper(_DISCONNECTREASONTYPE)
UserStatusSUCCESS = 0
ErrUserStatusKeyExpired = 37001
ErrUserStatusBanAccount = 37002
ErrUserStatusBanIp = 37003
ErrUserStatusRelogin = 37004
ErrUserStatusTakeLeave = 37005
ErrUserStatusAccountDeleting = 37010
UC_UserStatusZero = 0
UC_UserStatusRelogin = 501001
UC_UserStatusTakeLeave = 501002
UC_UserStatusDeviceDisconnected = 501003
DRT_None = 0
DRT_RefreshState = 1
DRT_RemoveDevice = 2
DRT_Ban = 3
DRT_DelAccount = 4
DRT_ResetPass = 5
DRT_ModifyPass = 6


_LOGINREQ = DESCRIPTOR.message_types_by_name['LoginReq']
_LOGINRES = DESCRIPTOR.message_types_by_name['LoginRes']
_BROADCASTRELOGIN = DESCRIPTOR.message_types_by_name['BroadcastRelogin']
_BROADCASTTAKELEAVE = DESCRIPTOR.message_types_by_name['BroadcastTakeLeave']
_BROADCASTDEVICEDISCONNECTED = DESCRIPTOR.message_types_by_name['BroadcastDeviceDisconnected']
_LOGOUTREQ = DESCRIPTOR.message_types_by_name['LogoutReq']
_LOGOUTRES = DESCRIPTOR.message_types_by_name['LogoutRes']
_DISCONNECTREQ = DESCRIPTOR.message_types_by_name['DisconnectReq']
_DISCONNECTRES = DESCRIPTOR.message_types_by_name['DisconnectRes']
_USERCONINFOLISTREQ = DESCRIPTOR.message_types_by_name['UserConInfoListReq']
_USERCONINFOLISTRES = DESCRIPTOR.message_types_by_name['UserConInfoListRes']
_USERCONINFO = DESCRIPTOR.message_types_by_name['UserConInfo']
_USERDEVICEDISCONNECTEDREQ = DESCRIPTOR.message_types_by_name['UserDeviceDisconnectedReq']
_USERDEVICEDISCONNECTEDRES = DESCRIPTOR.message_types_by_name['UserDeviceDisconnectedRes']
_NOTIFYDEVICEDISCONNECTEDREQ = DESCRIPTOR.message_types_by_name['NotifyDeviceDisconnectedReq']
_NOTIFYDEVICEDISCONNECTEDRES = DESCRIPTOR.message_types_by_name['NotifyDeviceDisconnectedRes']
LoginReq = _reflection.GeneratedProtocolMessageType('LoginReq', (_message.Message,), {
  'DESCRIPTOR' : _LOGINREQ,
  '__module__' : 'user_status_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.LoginReq)
  })
_sym_db.RegisterMessage(LoginReq)

LoginRes = _reflection.GeneratedProtocolMessageType('LoginRes', (_message.Message,), {
  'DESCRIPTOR' : _LOGINRES,
  '__module__' : 'user_status_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.LoginRes)
  })
_sym_db.RegisterMessage(LoginRes)

BroadcastRelogin = _reflection.GeneratedProtocolMessageType('BroadcastRelogin', (_message.Message,), {
  'DESCRIPTOR' : _BROADCASTRELOGIN,
  '__module__' : 'user_status_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.BroadcastRelogin)
  })
_sym_db.RegisterMessage(BroadcastRelogin)

BroadcastTakeLeave = _reflection.GeneratedProtocolMessageType('BroadcastTakeLeave', (_message.Message,), {
  'DESCRIPTOR' : _BROADCASTTAKELEAVE,
  '__module__' : 'user_status_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.BroadcastTakeLeave)
  })
_sym_db.RegisterMessage(BroadcastTakeLeave)

BroadcastDeviceDisconnected = _reflection.GeneratedProtocolMessageType('BroadcastDeviceDisconnected', (_message.Message,), {
  'DESCRIPTOR' : _BROADCASTDEVICEDISCONNECTED,
  '__module__' : 'user_status_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.BroadcastDeviceDisconnected)
  })
_sym_db.RegisterMessage(BroadcastDeviceDisconnected)

LogoutReq = _reflection.GeneratedProtocolMessageType('LogoutReq', (_message.Message,), {
  'DESCRIPTOR' : _LOGOUTREQ,
  '__module__' : 'user_status_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.LogoutReq)
  })
_sym_db.RegisterMessage(LogoutReq)

LogoutRes = _reflection.GeneratedProtocolMessageType('LogoutRes', (_message.Message,), {
  'DESCRIPTOR' : _LOGOUTRES,
  '__module__' : 'user_status_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.LogoutRes)
  })
_sym_db.RegisterMessage(LogoutRes)

DisconnectReq = _reflection.GeneratedProtocolMessageType('DisconnectReq', (_message.Message,), {
  'DESCRIPTOR' : _DISCONNECTREQ,
  '__module__' : 'user_status_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.DisconnectReq)
  })
_sym_db.RegisterMessage(DisconnectReq)

DisconnectRes = _reflection.GeneratedProtocolMessageType('DisconnectRes', (_message.Message,), {
  'DESCRIPTOR' : _DISCONNECTRES,
  '__module__' : 'user_status_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.DisconnectRes)
  })
_sym_db.RegisterMessage(DisconnectRes)

UserConInfoListReq = _reflection.GeneratedProtocolMessageType('UserConInfoListReq', (_message.Message,), {
  'DESCRIPTOR' : _USERCONINFOLISTREQ,
  '__module__' : 'user_status_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.UserConInfoListReq)
  })
_sym_db.RegisterMessage(UserConInfoListReq)

UserConInfoListRes = _reflection.GeneratedProtocolMessageType('UserConInfoListRes', (_message.Message,), {
  'DESCRIPTOR' : _USERCONINFOLISTRES,
  '__module__' : 'user_status_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.UserConInfoListRes)
  })
_sym_db.RegisterMessage(UserConInfoListRes)

UserConInfo = _reflection.GeneratedProtocolMessageType('UserConInfo', (_message.Message,), {
  'DESCRIPTOR' : _USERCONINFO,
  '__module__' : 'user_status_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.UserConInfo)
  })
_sym_db.RegisterMessage(UserConInfo)

UserDeviceDisconnectedReq = _reflection.GeneratedProtocolMessageType('UserDeviceDisconnectedReq', (_message.Message,), {
  'DESCRIPTOR' : _USERDEVICEDISCONNECTEDREQ,
  '__module__' : 'user_status_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.UserDeviceDisconnectedReq)
  })
_sym_db.RegisterMessage(UserDeviceDisconnectedReq)

UserDeviceDisconnectedRes = _reflection.GeneratedProtocolMessageType('UserDeviceDisconnectedRes', (_message.Message,), {
  'DESCRIPTOR' : _USERDEVICEDISCONNECTEDRES,
  '__module__' : 'user_status_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.UserDeviceDisconnectedRes)
  })
_sym_db.RegisterMessage(UserDeviceDisconnectedRes)

NotifyDeviceDisconnectedReq = _reflection.GeneratedProtocolMessageType('NotifyDeviceDisconnectedReq', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFYDEVICEDISCONNECTEDREQ,
  '__module__' : 'user_status_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.NotifyDeviceDisconnectedReq)
  })
_sym_db.RegisterMessage(NotifyDeviceDisconnectedReq)

NotifyDeviceDisconnectedRes = _reflection.GeneratedProtocolMessageType('NotifyDeviceDisconnectedRes', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFYDEVICEDISCONNECTEDRES,
  '__module__' : 'user_status_ext_pb2'
  # @@protoc_insertion_point(class_scope:pb.NotifyDeviceDisconnectedRes)
  })
_sym_db.RegisterMessage(NotifyDeviceDisconnectedRes)

_USERSTATUSEXTOBJ = DESCRIPTOR.services_by_name['UserStatusExtObj']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\242\002\003PB3'
  _USERSTATUSERR._serialized_start=1082
  _USERSTATUSERR._serialized_end=1302
  _USERSTATUSCMDID._serialized_start=1305
  _USERSTATUSCMDID._serialized_end=1442
  _DISCONNECTREASONTYPE._serialized_start=1445
  _DISCONNECTREASONTYPE._serialized_end=1597
  _LOGINREQ._serialized_start=47
  _LOGINREQ._serialized_end=144
  _LOGINRES._serialized_start=146
  _LOGINRES._serialized_end=176
  _BROADCASTRELOGIN._serialized_start=178
  _BROADCASTRELOGIN._serialized_end=273
  _BROADCASTTAKELEAVE._serialized_start=275
  _BROADCASTTAKELEAVE._serialized_end=328
  _BROADCASTDEVICEDISCONNECTED._serialized_start=330
  _BROADCASTDEVICEDISCONNECTED._serialized_end=457
  _LOGOUTREQ._serialized_start=459
  _LOGOUTREQ._serialized_end=522
  _LOGOUTRES._serialized_start=524
  _LOGOUTRES._serialized_end=535
  _DISCONNECTREQ._serialized_start=537
  _DISCONNECTREQ._serialized_end=584
  _DISCONNECTRES._serialized_start=586
  _DISCONNECTRES._serialized_end=601
  _USERCONINFOLISTREQ._serialized_start=603
  _USERCONINFOLISTREQ._serialized_end=623
  _USERCONINFOLISTRES._serialized_start=625
  _USERCONINFOLISTRES._serialized_end=676
  _USERCONINFO._serialized_start=679
  _USERCONINFO._serialized_end=830
  _USERDEVICEDISCONNECTEDREQ._serialized_start=832
  _USERDEVICEDISCONNECTEDREQ._serialized_end=915
  _USERDEVICEDISCONNECTEDRES._serialized_start=917
  _USERDEVICEDISCONNECTEDRES._serialized_end=944
  _NOTIFYDEVICEDISCONNECTEDREQ._serialized_start=946
  _NOTIFYDEVICEDISCONNECTEDREQ._serialized_end=1048
  _NOTIFYDEVICEDISCONNECTEDRES._serialized_start=1050
  _NOTIFYDEVICEDISCONNECTEDRES._serialized_end=1079
  _USERSTATUSEXTOBJ._serialized_start=1600
  _USERSTATUSEXTOBJ._serialized_end=2054
# @@protoc_insertion_point(module_scope)



import base64
import time
import signal
import threading
import qrcode_terminal

from mecord import store 
from mecord import xy_pb 
from mecord import utils 

def singleton(cls):
    _instance = {}

    def inner():
        if cls not in _instance:
            _instance[cls] = cls()
        return _instance[cls]
    return inner

@singleton
class User(object):
    logined = False
    login_data = None

    def __init__(self):
        self.checkLoginStatus()

    def checkLoginStatus(self):
        if store.groupUUID() and store.token():
            self.logined = True
            return True
        self.logined = False        
        
    def isLogin(self):
        self.checkLoginStatus()
        if self.logined == False:
            #try get login info once
            self.loginIfNeed()
        return self.logined
    
    def logout(self):
        store.clear()
        self.logined = False

    def loginIfNeed(self):
        if xy_pb.GetAigcDeviceInfo():
            self.checkLoginStatus()

    #     if self.isLogin() == False:
    #         #need login
    #         logincode = xy_pb.GetQrcodeLoginCode()
    #         if logincode:
    #             logincode_encoded = base64.b64encode(bytes(logincode, 'utf-8')).decode('utf-8').replace("==","fuckEqual")
    #             uuid = utils.generate_unique_id()
    #             qrcode = f"https://main_page.html?action=scan&code={logincode_encoded}&deviceCode=143383612&deviceId={uuid}"
    #             utils.displayQrcode(qrcode)
    #             # qrcode_terminal.draw(qrcode)
    #             # print(qrcode)
    #             # utils.displayQRcodeOnTerminal(qrcode)
    #             self.checkLoginComplete(logincode)
    #             print("waiting for scan qrcode & login complete ~~~")

    # def checkLoginComplete(self, qrcode):
    #     rst = xy_pb.CheckLoginLoop(qrcode)
    #     if rst == 1: #success
    #         print("login success")
    #         self.logined = True
    #     elif rst == -1:
    #         threading.Timer(1, self.checkLoginComplete, (qrcode, )).start()
    #     else: #fail
    #         print("login fail !!!")


import sys
import os
import argparse
import threading

from mecord import xy_pb 
from mecord import utils
from mecord import xy_user
from mecord import mecord_service
from mecord import mecord_widget
from mecord import store

parser = argparse.ArgumentParser(formatter_class=argparse.RawTextHelpFormatter)
subparsers = parser.add_subparsers()
parser_widget = subparsers.add_parser("deviceid", help="获取当前设备ID")
parser_widget = subparsers.add_parser("show_token", help="展示当前设备token")
parser_widget = subparsers.add_parser("add_token", help="填入其他设备token")
parser_widget = subparsers.add_parser("widget", help="widget模块")
parser_widget.add_argument("init", type=str, default=None, help="创建widget, 注意: 需要在空目录调用")
parser_widget.add_argument("public", type=str, default=None, help="发布模块")
parser_widget.add_argument("list", type=str, default=None, help="本地支持的widget列表")
parser_widget.add_argument("add", type=str, default=None, help="添加新的本地widget执行库")
parser_service = subparsers.add_parser("service", help="service模块")
parser_service.add_argument("start", type=str, default=None, help="start task loop service")

def service():
    if xy_user.User().isLogin() == False:
        print('please login first! \nUsage: mecord deviceid & Use Mecord Application scan it')
        return
    map = store.widgetMap()
    if len(map) == 0:
        print("please add widget first! \nUsage: mecord widget add [widget python path]")
        return
    if len(sys.argv) <= 2:
        print('please set command! Usage: mecord service start')
        return

    command = sys.argv[2]
    service = mecord_service.MecordService()
    if command == 'start':
        if service.is_running():
            print('Service is already running.')
        else:
            print('Starting service...')
            service.start()
    elif command == 'stop':
        if not service.is_running():
            print('Service is not running.')
        else:
            print('Stopping service...')
            service.stop()
    elif command == 'restart':
        print('Restarting service...')
        service.restart()
    elif command == 'status':
        if service.is_running():
            print('Service is running.')
        else:
            print('Service is not running.')
    else:
        print("Unknown command:", command)
        print("Usage: python service.py [start|stop|restart|status]")
        
def widget():
    if xy_user.User().isLogin() == False:
        print('please login first! \nUsage: mecord deviceid & Use Mecord Application scan it')
        return
    if len(sys.argv) <= 2:
        print('please set command! Usage: mecord widget [init|publish]')
        return

    command = sys.argv[2] 
    work_path = os.getcwd()
    if len(sys.argv) > 3:
        work_path = sys.argv[3]
    if command == 'init':
        mecord_widget.createWidget(work_path)
    elif command == 'publish':
        mecord_widget.publishWidget(work_path)
    elif command == 'list':
        map = store.widgetMap()
        if len(map) == 0:
            print("local widget is empty")
        maxJust = 20
        for it in map:
            if len(it) > maxJust:
                maxJust= len(it)
        for it in map:
            print(f"{it.ljust(maxJust + 4)} {map[it]}")
    elif command == 'add':
        mecord_widget.addWidget(work_path)
    else:
        print("Unknown command:", command)
        print("Usage: mecord widget [init|publish]")

_max_checkdevice_count = 300 #loop waiting 5min
_cur_checkdevice_count = 0
def checkDeviceInfo():
    global _max_checkdevice_count
    global _cur_checkdevice_count
    if _cur_checkdevice_count > _max_checkdevice_count:
        return
    if xy_pb.GetAigcDeviceInfo():
        if store.isCreateWidget():
            mecord_widget.createDemoWidget()
    else:
        _cur_checkdevice_count += 1
        threading.Timer(1, checkDeviceInfo, ()).start()
        
def deviceid():
    global _cur_checkdevice_count
    xy_user.User().loginIfNeed()
    uuid = utils.generate_unique_id()
    utils.displayQrcode(f"https://main_page.html?action=scanbind&deviceId={uuid}")
    print(f"your deviceid is : {uuid}")
    _cur_checkdevice_count = 0
    checkDeviceInfo()
        
def joinToken():
    sp = store.Store()
    data = sp.read()

    if len(sys.argv) <= 2:
        print('can not found token! Usage: mecord add_token {token}')
        return
    if "token" in data and len(data["token"]) > 0:
        print('warning! token has been override!')
        
    store.clear()
    token = sys.argv[2] 
    data["token"] = token
    sp.write(data)

def showToken():
    t = store.token()
    print(f"your token is : {t}")
    utils.displayQrcode(t)

module_func = {
    "widget": widget,
    "service": service,
    "deviceid": deviceid,
    "show_token": showToken,
    "add_token": joinToken,
}

def main():
    if len(sys.argv) < 2:
        return

    module = sys.argv[1]
    if module in module_func:
        module_func[module]()
    else:
        print("Unknown command:", module)
        print("Usage: mecord [deviceid|show_token|add_token|service|widget]")
        sys.exit(0)
        
if __name__ == '__main__':
        main()



<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>Title</title>
    <script type="text/javascript" src="./MekongJS.js"></script>
</head>
<body>
    Hello World
    </br>
    <button class="submit" onclick="submit()">Test Task</button>

    <script>
    function submit(){
        var params = {
            "postType": "generalPost", // eneralPost, post, preview
            "taskType": "text",  //image, video, audio, text
            "fn_name": "test",
            "param": {
                "text":"Hello World"
            }
        };

        MekongJS.excuting(JSON.stringify(params), function(res) { console.log(res); });
    }
    </script>
</body>
</html>


import ftplib
import os

def upload(local_path, remote_dir='', ftp=None):
    if not ftp:
        ftp = ftplib.FTP('192.168.3.220')
        ftp.login('xinyu100', 'xinyu100.com')

    remote_path = '1TB01/data/mecord/' + remote_dir
    try:
        ftp.cwd(remote_path)
    except ftplib.error_perm as e:
        if e.args[0].startswith('550'):
            # 如果远程目录不存在，则创建它
            ftp.mkd(remote_path)
            ftp.cwd(remote_path)

    if os.path.isfile(local_path):
        with open(local_path, 'rb') as file:
            ftp.storbinary(f'STOR {os.path.basename(local_path)}', file)
    elif os.path.isdir(local_path):
        for filename in os.listdir(local_path):
            local_file = os.path.join(local_path, filename)
            if os.path.isfile(local_file):
                with open(local_file, 'rb') as file:
                    ftp.storbinary(f'STOR {filename}', file)
            elif os.path.isdir(local_file):
                subdir = os.path.join(remote_dir, filename)
                upload(local_file, subdir, ftp)
    ftp.quit()



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()
setuptools.setup(
    name="mecord-cli",
    version="0.1.11",
    author="pengjun",
    author_email="mr_lonely@foxmail.com",
    description="mecord tools",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/mecordofficial",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    py_modules=[],
    # data_files=[
    #     ('widget_template', [
    #         'mecord/widget_template/config.json',
    #         'mecord/widget_template/icon.png',
    #         'mecord/widget_template/index.html'
    #         ]),
    #     ('script_template', [
    #         'mecord/scrip_template/main.py',
    #         'mecord/scrip_template/run.py'
    #         ])
    # ],
    install_requires=[
        'requests',
        'uuid',
        'qrcode',
        'Image',
        'pillow',
        'protobuf',
        'psutil',
        'qrcode-terminal',
        'pynvml'

    ],
    dependency_links=[],
    entry_points={
        'console_scripts':[
            'mecord = mecord.main:main'
        ]
    },
    # scripts=[
    #     'mecord/upload.py'
    # ],
    python_requires='>=3.4',
)


import os
import json

def singleton(cls):
    _instance = {}

    def inner():
        if cls not in _instance:
            _instance[cls] = cls()
        return _instance[cls]
    return inner

@singleton
class Store(object):
    def __init__(self):
        self.path = os.path.join(os.path.dirname(os.path.abspath(__file__)), "data.json")
        
        if not os.path.exists(self.path):
            with open(self.path, 'w') as f:
                json.dump({}, f)
                
    def read(self):
        with open(self.path, 'r') as f:
            data = json.load(f)
            
        return data
    
    def write(self, data):
        with open(self.path, 'w') as f:
            json.dump(data, f)


def groupUUID():
    sp = Store()
    read_data = sp.read()
    if "groupUUID" in read_data:
        return read_data["groupUUID"]
    else:
        return ""
    
def isCreateWidget():
    sp = Store()
    read_data = sp.read()
    if "isCreateWidget" in read_data:
        return read_data["isCreateWidget"]
    else:
        return False
    
def finishCreateWidget():
    sp = Store()
    read_data = sp.read()
    read_data["isCreateWidget"] = False
    sp.write(read_data)
    
def token():
    sp = Store()
    read_data = sp.read()
    if "token" in read_data:
        return read_data["token"]
    else:
        return ""
    
def widgetMap():
    sp = Store()
    read_data = sp.read()
    if "widgets" in read_data:
        return read_data["widgets"]
    else:
        return {}
    
def insertWidgets(widget_id, path):
    sp = Store()
    read_data = sp.read()
    if "widgets" not in read_data:
        read_data["widgets"] = {}
    widgetsMap = read_data["widgets"]
    widgetsMap[widget_id] = path
    for k in list(widgetsMap.keys()):
        if os.path.exists(widgetsMap[k]) == False:
            del widgetsMap[k]
    sp.write(read_data)

def writeDeviceInfo(data):
    sp = Store()
    read_data = sp.read()
    read_data["deviceInfo"] = data
    sp.write(read_data)
    
def readDeviceInfo():
    sp = Store()
    read_data = sp.read()
    if "deviceInfo" in read_data:
        return read_data["deviceInfo"]
    else:
        return {}
    
def clear():
    sp = Store()
    sp.write("{}")
    read_data = sp.read()